%
%  INPUT DATA FORMAT FOR DKMT PLATE BENDING
%
%  Written by Erwin Tirta Winata and Charles Julius Salim
%  Petra Christian University, August-December 2015
%

%  Title of the problem:
Project_Title='DKMT Element';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  3  3  2  0.5  6  2  1  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Circle_Nodes2(5,2); % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	12	8	7
2	1	8	4	3
3	1	6	11	12
4	1	8	3	7
5	1	4	1	3
6	1	13	9	8
7	1	9	4	8
8	1	3	2	6
9	1	3	1	2
10	1	12	13	8
11	1	13	14	9
12	1	18	14	13
13	1	17	13	12
14	1	19	14	18
15	1	11	17	12
16	1	7	6	12
17	1	13	17	18
18	1	11	16	17
19	1	11	6	5
20	1	3	6	7
21	1	2	5	6
22	1	11	5	10
23	1	16	10	15
24	1	11	10	16];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1	0	1	1		0	0	0
 2	0	1	0		0	0	0
 5	0	1	0		0	0	0
10	0	1	0		0	0	0
15	1	1	1		0	0	0
16	1	1	1		0	0	0
17	1	1	1		0	0	0
18	1	1	1		0	0	0
19	1	1	1		0	0	0
14	0	0	1		0	0	0
 9	0	0	1		0	0	0
 4  0	0	1		0	0	0];


CoordCont=[1 2 5 10 15 16 17 18 19 14 9 4 1];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  10.92 0.3 2];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:24]';
Body_f= [N_b  ones(24,1)   zeros(24,1)   zeros(24,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Thin plate solutions
%  l/h=10 ---> 2.218E-09, thick plate theory, approximately: 2.5E-9
%  L/h=100 ---> 2.218E-06
%  L/h=10000 ---> 2.218
