%
%  INPUT DATA FORMAT FOR DKMT PLATE BENDING
%
%  Written by Erwin Tirta Winata and Charles Julius Salim
%  Petra Christian University, August-December 2015
%

%  Title of the problem:
Project_Title='DKMT Element';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  3  3  2  0.5  6  2  0  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Circle_Nodes2(5,3); % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	8	3	7
2	1	27	21	20
3	1	19	20	12
4	1	29	22	28
5	1	19	12	11
6	1	7	12	13
7	1	6	11	12
8	1	26	19	18
9	1	26	25	33
10	1	11	6	5
11	1	6	3	2
12	1	3	4	1
13	1	2	3	1
14	1	8	14	15
15	1	6	2	5
16	1	28	22	21
17	1	8	4	3
18	1	6	7	3
19	1	6	12	7
20	1	21	15	14
21	1	9	8	15
22	1	4	8	9
23	1	7	14	8
24	1	15	16	9
25	1	22	23	16
26	1	16	15	22
27	1	30	36	37
28	1	30	23	29
29	1	29	36	30
30	1	21	22	15
31	1	29	23	22
32	1	20	21	14
33	1	26	33	34
34	1	7	13	14
35	1	13	12	20
36	1	27	28	21
37	1	35	29	28
38	1	34	27	26
39	1	14	13	20
40	1	29	35	36
41	1	28	34	35
42	1	18	19	11
43	1	26	27	19
44	1	19	27	20
45	1	34	28	27
46	1	25	32	33
47	1	10	18	11
48	1	17	18	10
49	1	5	10	11
50	1	25	26	18
51	1	24	25	17
52	1	25	18	17
53	1	32	24	31
54	1	25	24	32];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1	0	1	1		0	0	0
 2	0	1	0		0	0	0
 5	0	1	0		0	0	0
10	0	1	0		0	0	0
17	0	1	0		0	0	0
24	0	1	0		0	0	0
31	1	1	1		0	0	0
32	1	1	1		0	0	0
33	1	1	1		0	0	0
34	1	1	1		0	0	0
35	1	1	1		0	0	0
36	1	1	1		0	0	0
37	1	1	1		0	0	0
30	0	0	1		0	0	0
23	0	0	1		0	0	0
16	0	0	1		0	0	0
 9	0	0	1		0	0	0
 4	0	0	1		0	0	0];


CoordCont=[1 2 5 10 17 24 31 32 33 34 35 36 37 30 23 16 9 4 1];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  10.92 0.3 2];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:54]';
Body_f= [N_b  ones(54,1)   zeros(54,1)   zeros(54,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Thin plate solutions
%  l/h=10 ---> 2.218E-09, thick plate theory, approximately: 2.5E-9
%  L/h=100 ---> 2.218E-06
%  L/h=10000 ---> 2.218
