%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 28 June 2006
%  Modifications:
%

%  Title of the problem:
Project_Title='A Quarter of Circular CL-U Plate Bending (34 Nodes)';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  1  3  3  2  0  6  2  1  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
1	0	0
2	10	0
3	7.0711	7.0711
4	0	10
5	16.466	0
6	14.26	8.2332
7	8.2332	14.26
8	0	16.466
9	24.009	0
10	22.181	9.1878
11	16.977	16.977
12	9.1878	22.181
13	0	24.009
14	32.524	0
15	30.932	10.05
16	26.312	19.117
17	19.117	26.312
18	10.05	30.932
19	0	32.524
20	41.933	0
21	40.505	10.853
22	36.315	20.967
23	29.651	29.651
24	20.967	36.315
25	10.853	40.505
26	0	41.933
27	50	0
28	48.746	11.126
29	45.048	21.694
30	39.092	31.174
31	31.174	39.092
32	21.694	45.048
33	11.126	48.746
34	0	50 ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 5  0  1  0   0  0  0
 9  0  1  0   0  0  0
14  0  1  0   0  0  0
20  0  1  0   0  0  0
27  1  1  1   0  0  0
 4  0  0  1   0  0  0
 8  0  0  1   0  0  0
13  0  0  1   0  0  0
19  0  0  1   0  0  0
26  0  0  1   0  0  0
34  1  1  1   0  0  0
28  1  1  1   0  0  0
29  1  1  1   0  0  0
30  1  1  1   0  0  0
31  1  1  1   0  0  0
32  1  1  1   0  0  0
33  1  1  1   0  0  0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:47 ]';
Body_f= [ N_b  -1E-6*ones(47,1)  zeros(47,1)  zeros(47,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
