%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 28 June 2006
%  Modifications: 
%

%  Title of the problem:
Project_Title='A Quarter of Circular CL-U Plate Bending (43 Nodes)';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  1  3  3  2  0  6  2  1  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
1	0	0
2	8	0
3	5.6569	5.6569
4	0	8
5	13.173	0
6	11.408	6.5865
7	6.5865	11.408
8	0	13.173
9	19.207	0
10	17.745	7.3503
11	13.582	13.582
12	7.3503	17.745
13	0	19.207
14	26.019	0
15	24.745	8.0403
16	21.05	15.294
17	15.294	21.05
18	8.0403	24.745
19	0	26.019
20	33.547	0
21	32.404	8.6825
22	29.052	16.773
23	23.721	23.721
24	16.773	29.052
25	8.6825	32.404
26	0	33.547
27	41.743	0
28	40.696	9.2887
29	37.609	18.112
30	32.636	26.026
31	26.026	32.636
32	18.112	37.609
33	9.2887	40.696
34	0	41.743
35	50	0
36	49.039	9.7545
37	46.194	19.134
38	41.573	27.779
39	35.355	35.355
40	27.779	41.573
41	19.134	46.194
42	9.7545	49.039
43	0	50 ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 5  0  1  0   0  0  0
 9  0  1  0   0  0  0
14  0  1  0   0  0  0
20  0  1  0   0  0  0
27  0  1  0   0  0  0
35  1  1  1   0  0  0
 4  0  0  1   0  0  0
 8  0  0  1   0  0  0
13  0  0  1   0  0  0
19  0  0  1   0  0  0
26  0  0  1   0  0  0
34  0  0  1   0  0  0
43  1  1  1   0  0  0
36  1  1  1   0  0  0
37  1  1  1   0  0  0
38  1  1  1   0  0  0
39  1  1  1   0  0  0
40  1  1  1   0  0  0
41  1  1  1   0  0  0
42  1  1  1   0  0  0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:62 ]';
Body_f= [ N_b  -1E-6*ones(62,1)  zeros(62,1)  zeros(62,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
