function [TRI, Nelem] = Delaunay_order(Coord)

%  [TRI, Nelem] = Delaunay_order(Coord)
%  returns triangular connectivity in the anticlockwise
%  direction and the total number of triangles
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 30 August 2005
%
%  Input
%  Coord:  Coordinate of the node
%
%  Output
%  TRI:  Triangular connectivity
%  Nelem:  Total number of elements in the structure
%
Lnods=delaunay( Coord(:,1), Coord(:,2));
Nelem=size(Lnods,1);
%
%  Reorder TRI
%
TRI=Lnods;
for Ielem=1:Nelem
    X1=Coord(Lnods(Ielem,1),1);
    Y1=Coord(Lnods(Ielem,1),2);
    X2=Coord(Lnods(Ielem,2),1);
    Y2=Coord(Lnods(Ielem,2),2);
    X3=Coord(Lnods(Ielem,3),1);
    Y3=Coord(Lnods(Ielem,3),2);
    A2=det([1 X1 Y1; 1 X2 Y2; 1 X3 Y3]);
    if A2<0
        TRI(Ielem,2)=Lnods(Ielem,3);
        TRI(Ielem,3)=Lnods(Ielem,2);
    end
end
