function Bs = Deriv_s(Phi, DxPhi, DyPhi, n_Nodes)
 
%  Establishing shearing strain-displacement
%  matrix at sampling point for a plate element 
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 31 Jan 2006
%
%  Input
%  Phi:  Row matrix of shape function values at a sampling point
%  DxPhi, DyPhi:  Row matrix of shape function derivatives 
%                 with respect to x and y, respectively, at a sampling point
%  n_Nodes:  Number of nodes in the influence domain
%
%  Output
%  Bs:  The shearing strain-displacement matrix for plate
%
Bs=zeros(2,3*n_Nodes);
for i_d=1:n_Nodes
    Bs(1, 3*i_d-2)=DxPhi(1,i_d);
    Bs(1, 3*i_d-1)= Phi(1,i_d);
    Bs(2, 3*i_d-2)=DyPhi(1,i_d);
    Bs(2, 3*i_d)= Phi(1,i_d);
end