function [Project_Title, Ndofn, Ntype, P_order, N_layer, theta_type, theta, ...
          Nsamp, Ngaus, shear_type, Npoin, TRI, Nelem, Nnode, Nsvab, Coord,  ...
          Matno, Props, Ifpre, Fixed, Point, Trac_f, NTrac_f, Body_f] = ...
          Echo_data (Input_file_name)

%  Giving general information of the input data file and feeding
%  the necessary input for subsequent calculation processes
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 16 April 2004
%  Last modification: 15 March 2006
%
%  Input
%  Input_file_name  
%
%  Output
%  All of variables needed for subsequent calculation processes
%
eval(Input_file_name);
Project_Title
%
Ndofn=Control_cards(1,1);
fprintf('Number of degrees of freedom per nodal point: %d \n', Ndofn);
Ntype=Control_cards(1,2);
if Ntype==1
   fprintf('Gaussian correlation function is employed. \n')
elseif Ntype==2
   fprintf('Quartic spline correlation function is employed. \n')
elseif Ntype==3
   fprintf('Cubic spline correlation function is employed. \n')
else
   error('Wrong type of correlation function!!');
end
P_order=Control_cards(1,3);
if P_order==1
   fprintf('Kriging interpolation with linear basis function. \n')
elseif P_order==2
   fprintf('Kriging interpolation with quadratic basis function. \n')
elseif P_order==3
   fprintf('Kriging interpolation with cubic basis function. \n')
elseif P_order==4
   fprintf('Kriging interpolation with quartic basis function. \n')
elseif P_order==5
   fprintf('Kriging interpolation with bi-linear basis function. \n')
elseif P_order==6
   fprintf('Kriging interpolation with bi-quadratic basis function. \n')
elseif P_order==7
   fprintf('Kriging interpolation with bi-cubic basis function. \n')
else
   error('Wrong polynomial order!!');
end
N_layer=Control_cards(1,4);
if (N_layer>=1 & N_layer<=5)
   fprintf('The number of influence layer(s): %d \n', N_layer)
else
   error('Wrong number of influence layers!!');
end
theta_type=Control_cards(1,5);
theta=Control_cards(1,6);
if theta_type==1
   fprintf('The correlation parameter is constant through out the elements: \n')
   fprintf('theta= %5.2f \n', theta)
elseif theta_type==2
   if (theta>=0) & (theta<=1)
      fprintf('The correlation parameter is adapted to ')
      fprintf('the number of nodes in the DOI with \n')
      fprintf('the upper bound factor: %5.2f \n', theta)
   else
      error('Wrong factor of theta!!');
   end
else
   error('Wrong type of correlation parameter!!');
end
Nsamp=Control_cards(1,7);
switch Nsamp
   case {1, 3, 4, 6, 7, 12, 13}
   fprintf('The number of sampling points for the integration ... \n')
   fprintf('of the triangular elements: %d \n', Nsamp) 
   otherwise
   error('Wrong number of sampling points!!');
end
Ngaus=Control_cards(1,8);
fprintf('The order of gaussian numerical integration: %d \n', Ngaus)
Mesh_gen=Control_cards(1,9);
switch Mesh_gen
    case 0
    fprintf('Mesh is manually generated \n')
    case 1
    fprintf('Mesh is automatically generated \n')
    otherwise
    error('Wrong mesh generator code!!');
end
shear_type=Control_cards(1,10);
switch shear_type
    case 1
    fprintf('Shear forces are calculated from shear strains')
    case 2
    fprintf('Shear forces are calculated using kriging from nodal moments')
    case 3
    fprintf('Shear forces are calculated using kriging from nodal displacements')
    otherwise
    error('Wrong shear_type!!');
end
%
Npoin=size(Node_cards,1);  Ndime=size(Node_cards,2)-1;
fprintf('\nTotal number of nodal points in the structure: %d \n', Npoin);
fprintf('Number of coordinate components required to ');
fprintf('define each nodal points: %d \n', Ndime);
%
Coord=Node_cards;
Coord(:,1)=[];
%
switch Mesh_gen
    case 0
    Nelem=size(Element_cards,1);
    Matno=Element_cards(:,2);
    TRI=Element_cards;
    TRI(:,[1 2])=[];
    case 1
    [TRI, Nelem] = Delaunay_order(Coord);
    Matno=ones(Nelem,1);
    otherwise
    error('Wrong mesh generator code!!');
end
%
Nnode=size(TRI,2);
fprintf('\nTotal number of elements in the structure: %d \n', Nelem);
fprintf('Number of nodes per element: %d \n', Nnode);
%
Nmats=size(Material_cards,1);
fprintf('\nTotal number of different materials in the structure: %d \n', Nmats)
%
Nsvab=Npoin*Ndofn;
fprintf('\nNumber of global structural variables (DOF): %d \n', Nsvab)
%
Props=Material_cards(:,2:end);
%
Ifpre1=Restrained_cards(:,1: (1+Ndofn));
Fixed1=Restrained_cards(:,1);
Fixed1=[ Fixed1  Restrained_cards(:,(Ndofn+2):end) ];
Ifpre = Node2eqns(Ifpre1, Nsvab);  %  Vector of displacement B.C.'s codes
Fixed = Node2eqns(Fixed1, Nsvab);  %  Vector of the values of prescribed displacements
%
Point=Node2eqns(Applied_load_cards, Nsvab);
%
NTrac_f=size(Trac_f,1);
fprintf('\nNumber of line segments with traction force: %d \n', NTrac_f)
