function x1 = Eqns2node(x, Ndofn, Nonzero_x)
%
%  Converting the format of x to x1,
%  which is the data matrix in 'per nodes' format
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 19 December 2003
%
%  Input
%  x:  Vector of data, which is sorted by equation numbers
%  Ndofn: Number of degrees of freedom per node
%  Nonzero_x:  indices of nonzero elements of x
%
%  Output
%  x1:  Data matrix in 'per nodes' format
%       The nodes in which all dofs are zeros are deleted
%
%  Example
%  x=[1 0 1 0 1 0 1 0 1 0]';
%  Ndofn=2;
%  Nonzero_x = [1 3 5 7 ]';
%  x1 ---> [ 1 1 0; 2 1 0; 3 1 0; 4 1 0]
%
x1= (1 : length(x)/Ndofn)';
x1=[ x1 zeros(size(x1,1),Ndofn) ];
for Ix = 1:length(x)
    if mod(Ix,Ndofn) ~= 0
       Col=mod(Ix,Ndofn)+1;
    else
       Col=Ndofn+1;
    end   
    x1( ceil(Ix/Ndofn), Col ) = x(Ix);
end 

Remain_row = Del_same(ceil(Nonzero_x/Ndofn));
x1=x1(Remain_row,:);