function [Posgp, Weigp] = Gaussq (Ngaus)

%  [Posgp, Weigp] = Gaussq (Ngaus)
%
%  To set up the sampling point positions and 
%  weighting factors for numerical integration
%  (only available for Ngaus <= 4)
%  
%  Written by: Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 14 March 2004
%  Modification: 
%
%  Input
%  Ngaus:  The order of Gaussian numerical integration rule to be employed
%
%  Output
%  Posgp:  The sampling point positions
%  Weigp:  The weighting factors
%
if Ngaus==1
    Posgp=0;
    Weigp=2;
elseif Ngaus==2
    Posgp=[ -1/sqrt(3)  1/sqrt(3) ];
    Weigp=[ 1  1 ];
elseif Ngaus==3
    Posgp=[ -sqrt(0.6)  0  sqrt(0.6) ];
    Weigp=[ 5/9  8/9  5/9 ];
elseif Ngaus==4
    Posgp=[ -sqrt((3+sqrt(4.8))/7)  -sqrt((3-sqrt(4.8))/7) ...
             sqrt((3-sqrt(4.8))/7)   sqrt((3+sqrt(4.8))/7)];
    Weigp=[ 1/2-sqrt(30)/36  1/2+sqrt(30)/36  1/2+sqrt(30)/36  1/2-sqrt(30)/36 ];
else  
    Msg=[ 'Not available for Ngaus=' num2str(Ngaus) ];  
    error(Msg);  
end    
   