function GI_dof_e = Global_dof (Nodes, n_Nodes, Ndofn)
                                
%  GI_dof_e = Global_dof (Nodes, n_Nodes, Ndofn)
%
%  To obtain global (structural) parameter indices for an element
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 2 September 2005
%  Modification:  8 September 2005
%
%  Input 
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Ndofn  : Number of degrees of freedom per node
%
%  Output
%  GI_dof_e:  Global index of the parameters (dof) per each element
%

%  GI_dof_n:  Global index of the parameters (dof) per each node
GI_dof_n=zeros(Ndofn,1);
GI_dof_e=zeros(Ndofn*n_Nodes,1);  
%
for Inode=1:n_Nodes
    Nodei=Nodes(1,Inode);
    for Idofn=1:Ndofn
        GI_dof_n(Idofn,1)=(Nodei-1)*Ndofn + Idofn;
    end
    a=Ndofn*(Inode-1)+1;  b=Ndofn*Inode;
    GI_dof_e(a:b,1) = GI_dof_n;
end
