%
%  Main Program for Linear Elastic Analysis of Plate Bending
%  by Kriging Finite Element Method
%  - Standard K-FEM Formulation
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 6-8 October 2005
%  Last modification: 16 March 2006, 8 Feb 2007
%
%  Modified for MITC3+ element with Kriging
%  by Sebastian, 15 April 2021 
%
clear; clc; tic;
Input_file_name='Patch1MeshRapi_dat';
% Out_file_name = strrep(Input_file_name,'_dat','_out');
% if strcmp(Out_file_name, Input_file_name)
%     disp('Wrong name of data input file!')
%     error('The data input file have to be ended by "_dat" ')
% end
[Project_Title, Ndofn, Cor_type, P_order, N_layer, theta_type, theta, ...
 Nsamp, Ngaus, shear_type, Npoin, TRI, Nelem, Nnode, Nsvab, Coord,  ...
 Matno, Props, Ifpre, Fixed, Point, Trac_f, NTrac_f, Body_f] = Echo_data (Input_file_name);
clear  Input_file_name
clear   Nnode
Plot_Undeform_TRI (Project_Title, TRI, Coord, Npoin)
%
%  Node numbers in each influence domain
%
fprintf('\n   Searching node numbers in each influence domain ... \n ')
n_Nodes=zeros(Nelem,1);
for Ielem=1:Nelem
    Nodes_I = Nodes_DOI( Ielem, N_layer, TRI);
    n_Nodes(Ielem,1) = size(Nodes_I,2);
    if (P_order==7 && N_layer==4 && n_Nodes(Ielem,1)<21) || ...
       (P_order==4 && N_layer==4 && n_Nodes(Ielem,1)<21)
        Nodes_I = Nodes_DOI( Ielem, N_layer+1, TRI);
        n_Nodes(Ielem,1) = size(Nodes_I,2);
    end
    Nodes(Ielem,1) = { Nodes_I };
end
Nodes;
clear Nodes_I
% clear N_layer
%
%  Adjusting the correlation parameter
%
switch theta_type
    case 1
    theta = ones(Nelem,1)*theta;
    case 2
    switch Cor_type
        case 1
        Up_fact=theta; Low_fact=1-theta;
        Upper_b=zeros(Nelem,1);  Lower_b=zeros(Nelem,1);
        for Ielem=1:Nelem
            if (n_Nodes(Ielem,1)>=3 && n_Nodes(Ielem,1)<10)
                Upper_b(Ielem,1) = 0.34*n_Nodes(Ielem,1)-0.7;
                Lower_b(Ielem,1) = 0.08286*n_Nodes(Ielem,1)-0.2386;
            elseif n_Nodes(Ielem,1)<=55
                Upper_b(Ielem,1) = -2.484e-3*n_Nodes(Ielem,1)^2 + ...
                0.3275*n_Nodes(Ielem,1) - 0.2771;
                Lower_b(Ielem,1) = -8.364e-4*n_Nodes(Ielem,1)^2 + ...
                0.1204*n_Nodes(Ielem,1) - 0.5283;
            else
                Upper_b(Ielem,1) = 0.05426*n_Nodes(Ielem,1)+7.237;
                Lower_b(Ielem,1) = 0.02840*n_Nodes(Ielem,1)+2.002;
            end
        end
        theta = Up_fact*Upper_b + Low_fact*Lower_b;
        case 2
        theta=zeros(Nelem,1);
        for Ielem=1:Nelem
            if (n_Nodes(Ielem,1)>=3 && n_Nodes(Ielem,1)<10)
               theta(Ielem,1) = 0.1329*n_Nodes(Ielem,1)-0.3290;
            else
               theta(Ielem,1) = 1;
            end
        end
    end
end
clear Upper_b Lower_b Up_fact Low_fact
% clear theta_type
%
%  Element Stiffness Assembly
%
fprintf('\n   Generating stiffness matrix... \n ')
Astiff=zeros(Nsvab,Nsvab);
Asload_b=zeros(Nsvab,1);
Asloadtrac=zeros(Nsvab,1);
% TRI_trac = Find_TRI_trac(Trac_f, NTrac_f, TRI);   % traction vector (unfinished)
%h = waitbar(0,'Generating stiffness matrix...');
for Ielem=1:Nelem
%     fprintf('Ielem: %d \n', Ielem);
    %  Nodes in the influence domain
    IMatno=Matno(Ielem);
    n_Nodes_I = n_Nodes(Ielem,1);
    Nodes_I = Nodes{ Ielem,1 };
    theta_I = theta(Ielem,1);
    Body_f_I = Body_f(Ielem,2:4);
    [Estiff, Rload, Au] = Stif_bodyps_MITC3plate( Ielem, TRI, Coord, IMatno, Props, Cor_type, ...
                           Nsamp, theta_I, P_order, Nodes_I, n_Nodes_I, Ndofn, Body_f_I);
    Astiff = Astiff + El_stiff2str (Estiff, Nodes_I, Nsvab, n_Nodes_I, Ndofn);
    Asload_b= Asload_b + El_load2str (Rload, Nodes_I, Nsvab, n_Nodes_I, Ndofn);
    AuG{Ielem,:}=Au;
    %waitbar(Ielem/Nelem,h)
%
%  Element Traction Assembly
%
%     for i_TRI=1:NTrac_f         
%     Ielemt=TRI_trac(i_TRI);         
%         if Ielem == Ielemt                  
%             Tload = Tracps_Krig (Nodes_I, n_Nodes_I, Coord, Props, IMatno, ...
%                          i_TRI, Trac_f, Ngaus, Ndofn, theta_I, Cor_type, P_order, Ielem, TRI, Au, Nsamp);
%             Asloadtrac = Asloadtrac + El_load2str (Tload, Nodes_I, Nsvab, n_Nodes_I, Ndofn);
%         end
%     end
end
% close(h)
clear  Estiff Rload Body_f_I h
clear Body_f
clear  TRI_trac i_TRI Ielem Nodes_I n_Nodes_I theta_I Rload
%
%  Applying nodal point forces
%
% Gload=Asload_b+Point+Asloadtrac;
Gload=Asload_b+Point;
clear Asload_b Point Asloadtrac
%
%  Imposing Displacement Boundary Conditions
%
[Mod_Astiff, Mod_Gload] = ...
Modify (Astiff, Gload, Nsvab, Ifpre, Fixed);
% clear  Astiff Gload
%
%  The solution of equations
%
%  Nonzero_Ifpre :  Equation indices of fixed dofs or 
%                   prescribed displacements
Nonzero_Ifpre = Nonzero_index (Ifpre, Fixed);
Xdisp = Solution (Nsvab, Mod_Astiff, Mod_Gload, Fixed, Nonzero_Ifpre);
size(Mod_Astiff)
% clear  Mod_Astiff Mod_Gload
toc
Xdisp(1,:)
% A=Astiff*Xdisp
% b=Mod_Gload
% c=Gloada
% Mewant=zeros(3,64)
% Mewant(2,:)=2
% Astiff*Xdisp
% Gload
% aaa=Astiff*Xdisp-Gload;
% Db=1E+6*[1.4652 0.4396 0; 0.4396 1.4652 0;0 0 0.5128]

% midisp=Xdisp(337:360,:);  %SSH_U_full span
% x13=Xdisp(37,:)           %Rhombic4
% X41=Xdisp(121,:)          %Rhombic8
% X145=Xdisp(433,:)         %Rhombic16
% X545=Xdisp(1633,:)        %Rhombic32

% Db=1600000*(0.5^3);
% normwc=u*Db*1000/(1*1)

%  Transverse displacement along x axis
% Xdisp(1:3:25,:)
% Xdisp(3:3:27,:)
% Xdisp([1 4 13 25 40 58 79],:)
% Xdisp([1 4 13 25 40 58 79 103 130 160 193],:)
% Xdisp([3 6 15 27 42 60 81 105 132 162 195],:)
% Xdisp([1 4 13 25 40 58 79 103 130 160 193 229 268 310 355 403 454 508 565],:)
% Xdisp([3 6 15 27 42 60 81 105 132 162 195 231 270 312 357 405 456 510 567],:)
% Xdisp(37,:)
% Xdisp([118 121 124],:)
% Transverse displacement along y axis
% Xdisp(1:24:171,:)
%
% Patch test
% Xdisp(1:3:73,:) 
% Xdisp(2:3:74,:) 
% Xdisp(3:3:75,:) 
%
%  Reactions
%
% React = Reaction (Astiff, Gload, Xdisp, Ndofn, Nonzero_Ifpre);
% clear  Astiff Gload
% React(:,2:end)
% sum(React(:,2:end))
% 
% Rel_Error_Rec
% Rel_Error_Cir

%  Constant Curvature
% w13= 0.5*1E-3*(0.12^2 + 0.12*0.06 + 0.06^2);
% theta_x13= 0.001*(0.12/2 + 0.06);
% theta_y13= -0.001*(0.12 + 0.06/2);
%  Constant Shear
% w13= 1E-6*(0.12 + 0.06)/2;
% theta_x13= -0.5E-6;
% theta_y13= 0.5E-6;

% 25 nodes
% (Xdisp(37,:)-w13) / w13
% (Xdisp(38,:)-theta_x13) / theta_x13 
% (Xdisp(39,:)-theta_y13) / theta_y13
% 81 nodes
% (Xdisp(130,:)-w13) / w13
% (Xdisp(131,:)-theta_x13) / theta_x13 
% (Xdisp(132,:)-theta_y13) / theta_y13
% 289 nodes
% (Xdisp(460,:)-w13) / w13
% (Xdisp(461,:)-theta_x13) / theta_x13 
% (Xdisp(462,:)-theta_y13) / theta_y13
% 1089 nodes
% disp( (Xdisp(1738,:)-w13) / w13 )
% disp( (Xdisp(1739,:)-theta_x13) / theta_x13 )
% disp( (Xdisp(1740,:)-theta_y13) / theta_y13 )
% disp(Xdisp(1738,:))
% disp(Xdisp(1739,:))
% disp(Xdisp(1740,:))
% Rel_Error_Patch1
% Rel_Error_Patch4
% Rel_Error_Patch4w
Go_Post

% Patch1_81_dat 
X=[1 3 5 7 9 19 21 23 25 27 37 39 41 43 45 55 57 59 61 63 73 75 77 79 81];

% Patch1_81_dat Delauny
% X=[1 3 5 7 9 24 20 15 25 27 43 37 44 40 45 62 55 57 59 63 73 75 77 79 81];

% Patch1_289_dat Delauny
% X=[1 5 9 13 17 86 64 49 88 92 152 132 154 142 155 220 202 206 210 230 273 277 281 285 289]; 

% Patch Test more than 32 element
Disp=zeros(75,1);
for i=1:25
Disp(i*3-2,:)=Xdisp(X(i)*3-2,1)
Disp(i*3-1,:)=Xdisp(X(i)*3-1,1)
Disp(i*3,:)=Xdisp(X(i)*3,1)
end
Moment75=zeros(3,25);
for a=1:25
Moment75(:,a)=Node_Moments(:,X(a));
end
Shear75=zeros(2,25);
for a=1:25
Shear75(:,a)=Node_Shears(:,X(a));
end