%
%  Post-processing Program for 
%  Linear Elastic Analysis of Plate Bending by Kriging Finite Element Method
%  - Standard K-FEM Formulation
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 16 March 2006
%  
%  Last modification: 16 March 2006
%  

% Cor_type=2; P_order=2; N_layer=2;
% theta_type=2; theta=0;
% shear_type=1;
theta=0.5;
%
%  Node numbers in each influence domain for post processing
%
fprintf('\n   Post-processing: Searching node numbers in each influence domain ... \n ')
n_Nodes=zeros(Nelem,1);
for Ielem=1:Nelem
    Nodes_I = Nodes_DOI( Ielem, N_layer, TRI);
    n_Nodes(Ielem,1) = size(Nodes_I,2);
    if (P_order==7 && N_layer==4 && n_Nodes(Ielem,1)<21) | ...
       (P_order==4 && N_layer==4 && n_Nodes(Ielem,1)<21)
        Nodes_I = Nodes_DOI( Ielem, N_layer+1, TRI);
        n_Nodes(Ielem,1) = size(Nodes_I,2);
    end
    Nodes(Ielem,1) = { Nodes_I };
end
clear Nodes_I
clear N_layer
%
%  Adjusting the correlation parameter for post processing
%
switch theta_type
    case 1
    theta = ones(Nelem,1)*theta;
    case 2
    switch Cor_type
        case 1
        Up_fact=theta; Low_fact=1-theta;
        Upper_b=zeros(Nelem,1);  Lower_b=zeros(Nelem,1);
        for Ielem=1:Nelem
            if (n_Nodes(Ielem,1)>=3 && n_Nodes(Ielem,1)<10)
                Upper_b(Ielem,1) = 0.34*n_Nodes(Ielem,1)-0.7;
                Lower_b(Ielem,1) = 0.08286*n_Nodes(Ielem,1)-0.2386;
            elseif n_Nodes(Ielem,1)<=55
                Upper_b(Ielem,1) = -2.484e-3*n_Nodes(Ielem,1)^2 + ...
                0.3275*n_Nodes(Ielem,1) - 0.2771;
                Lower_b(Ielem,1) = -8.364e-4*n_Nodes(Ielem,1)^2 + ...
                0.1204*n_Nodes(Ielem,1) - 0.5283;
            else
                Upper_b(Ielem,1) = 0.05426*n_Nodes(Ielem,1)+7.237;
                Lower_b(Ielem,1) = 0.02840*n_Nodes(Ielem,1)+2.002;
            end
        end
        theta = Up_fact*Upper_b + Low_fact*Lower_b;
        case 2
        theta=zeros(Nelem,1);
        for Ielem=1:Nelem
            if (n_Nodes(Ielem,1)>=3 && n_Nodes(Ielem,1)<10)
               theta(Ielem,1) = 0.1329*n_Nodes(Ielem,1)-0.3290;
            else
               theta(Ielem,1) = 1;
            end
        end
    end
end
clear theta_type Upper_b Lower_b Up_fact Low_fact

%  Bending and Twisting Moments and 
%  Shear Forces at Triangular Vertices
%
fprintf('\n   Computing moments and shears ... \n ')
Moments = zeros(3,3*Nelem);  Shears = zeros(2,3*Nelem);
switch shear_type
    case 1
%     h = waitbar(0,'Computing moments and shears ...');
    for Ielem=1:Nelem
        IMatno=Matno(Ielem);
        n_Nodes_I = n_Nodes(Ielem,1);
        Nodes_I = Nodes{ Ielem,1 };
        theta_I = theta(Ielem,1);
        [ Moments(:, (3*Ielem-2):(3*Ielem)), Shears(:, (3*Ielem-2):(3*Ielem)) ]= ...
        Moment_Shear_fun( Ielem, TRI, Coord, IMatno, Props, Cor_type, ...
                          theta_I, P_order, Nodes_I, n_Nodes_I, Ndofn, Xdisp, cell2mat(AuG(Ielem)));
        % waitbar(Ielem/Nelem,h)
    end
    % close(h)
    clear Ielem Imatno n_Nodes_I Nodes_I theta_I h
    %  Moment and Shear Averaging
    %
    [Node_Moments, Ave_Moments, Node_Shears, Ave_Shears] = ...
     Moment_Shear_ave(Npoin, TRI, Moments, Shears);
 
    case 2
    % h = waitbar(0,'Computing moments ...');
    for Ielem=1:Nelem
        IMatno=Matno(Ielem);
        n_Nodes_I = n_Nodes(Ielem,1);
        Nodes_I = Nodes{ Ielem,1 };
        theta_I = theta(Ielem,1);
        Moments(:, (3*Ielem-2):(3*Ielem))= ...
        Moment_fun( Ielem, TRI, Coord, IMatno, Props, Cor_type, ...
                    theta_I, P_order, Nodes_I, n_Nodes_I, Ndofn, Xdisp);
        % waitbar(Ielem/Nelem,h)
    end
    % close(h)
    clear Ielem Imatno n_Nodes_I Nodes_I theta_I h
    %
    %  Moment Averaging
    [Node_Moments, Ave_Moments] = Moment_ave(Npoin, TRI, Moments);
    %
    %  Calculating Shear Forces
    for Ielem=1:Nelem
        Nodes_I = Nodes{ Ielem,1 };
        theta_I = theta(Ielem,1);
        Shears(:, (3*Ielem-2):(3*Ielem))= ...
        Shear2_fun( Ielem, TRI, Coord, Cor_type, ...
                    theta_I, P_order, Nodes_I, Node_Moments);
    end
    %
    %  Shear Force Averaging
    [Node_Shears, Ave_Shears] = Shear_ave(Npoin, TRI, Shears);
    
    case 3
    % h = waitbar(0,'Computing moments and shears...');
    for Ielem=1:Nelem
        IMatno=Matno(Ielem);
        n_Nodes_I = n_Nodes(Ielem,1);
        Nodes_I = Nodes{ Ielem,1 };
        theta_I = theta(Ielem,1);
        [ Moments(:, (3*Ielem-2):(3*Ielem)), Shears(:, (3*Ielem-2):(3*Ielem)) ]= ...
        Moment_Shear_fun3( Ielem, TRI, Coord, IMatno, Props, Cor_type, ...
                    theta_I, P_order, Nodes_I, n_Nodes_I, Ndofn, Xdisp);
        % waitbar(Ielem/Nelem,h)
    end
    % close(h)
    clear Ielem Imatno n_Nodes_I Nodes_I theta_I h
    %  Moment and Shear Averaging
    %
    [Node_Moments, Ave_Moments, Node_Shears, Ave_Shears] = ...
     Moment_Shear_ave(Npoin, TRI, Moments, Shears);
     
    otherwise
    error('Wrong shear_type!!');
end
% Moments(:, (3*23-2):(3*23) )
% Shears(:, (3*6-2):(3*6) )
Node_Moments(:, [1 end])
% Mmidspan=Node_Moments(:,113:120); %for SSHU full span
% Smidspan=Node_Shears(:,113:120);  %for SSHU full span
toc
%
%  Saving all MATLAB arrays
%
%eval(['save ', Out_file_name])
%
%  Plotting
%
Ask_G='y';
while Ask_G == 'y'
   disp('Plotting option:')
   disp('1. Undeformed shape')
   disp('2. Undeformed shape with element numbers')
   disp('3. Deformed shape in 3D')
   disp('4. Deflection and rotation contours')
   disp('5. Moment contours, un-averaged')
   disp('6. Moment contours, averaged')
   disp('7. Shear contours, un-averaged')
   disp('8. Shear contours, averaged')
   disp('9. Exit')
   Plot_case=input('Which one do you want to plot? ');
   fprintf('\n\n')
   for icase=1:size(Plot_case,2)
      switch Plot_case(1,icase)
         case 1
         Plot_Undeform_TRI (Project_Title, TRI, Coord, Npoin)
         case 2
         Plot_Undeform (Project_Title, TRI, Coord, Nelem, Npoin)
         case 3
         Plot_Deform3D (Project_Title, TRI, Coord, Npoin, Xdisp, Ndofn)
         case 4
         Plot_Deform (TRI, Coord, Npoin, Xdisp, Ndofn)
         case 5
         Plot_Moments (TRI, Coord, Nelem, Moments)
         case 6
         Plot_Ave_Moments (TRI, Coord, Nelem, Ave_Moments)
         case 7
         Plot_Shears (TRI, Coord, Nelem, Shears)
         case 8
         Plot_Ave_Shears (TRI, Coord, Nelem, Ave_Shears)
         otherwise
         Ask_G='n';
      end
  end
end
