function [N, DN, C, S, L, A] = MITC_shape_f (TRI_coord, x)

%  To evaluate the shape functions and 
%  their derivatives at point x

%  Input
%  TRI_coord:  Matrix of nodal Cartesian coordinates of
%              the triangular element (Nnode x 2)
%  x:  Coordinate of the point of interest
%  xi_Isamp: Coordinate of the sampling points in natural coordinate system
%
%  Output
%  N:   The standard values of shape function matrix at point x
%  DN:  The standard values of shape function derivative matrix at point x
%       [ DxN; DyN ]
%  C,S:  The cosinus and sinus direction of the triangle
%  L:  The length of each edges of triangle
%  A:  The area of the triangle
   
%  Two times of the area of the triangle
A2 = det( [ [1 ; 1; 1] TRI_coord] );
A=0.5*A2;

%  Shape functions
%
N=zeros(1,3);
N(1,1) = (  (TRI_coord(2,1)*TRI_coord(3,2)-TRI_coord(3,1)*TRI_coord(2,2)) ...
          + (TRI_coord(2,2)-TRI_coord(3,2))*x(1) ...
          + (TRI_coord(3,1)-TRI_coord(2,1))*x(2) ) / A2;   
%             
N(1,2) = (  (TRI_coord(3,1)*TRI_coord(1,2)-TRI_coord(1,1)*TRI_coord(3,2)) ...
         + (TRI_coord(3,2)-TRI_coord(1,2))*x(1) ...
         + (TRI_coord(1,1)-TRI_coord(3,1))*x(2) ) / A2;     
%             
N(1,3) = (  (TRI_coord(1,1)*TRI_coord(2,2)-TRI_coord(2,1)*TRI_coord(1,2)) ...
         + (TRI_coord(1,2)-TRI_coord(2,2))*x(1) ...
         + (TRI_coord(2,1)-TRI_coord(1,1))*x(2) ) / A2;     
           
%  Shape function derivatives
%
DN=zeros(2,3);
DN(1,1) = (TRI_coord(2,2)-TRI_coord(3,2))/A2;
DN(2,1) = (TRI_coord(3,1)-TRI_coord(2,1))/A2;
%
DN(1,2) = (TRI_coord(3,2)-TRI_coord(1,2))/A2;
DN(2,2) = (TRI_coord(1,1)-TRI_coord(3,1))/A2;
%
DN(1,3) = (TRI_coord(1,2)-TRI_coord(2,2))/A2;
DN(2,3) = (TRI_coord(2,1)-TRI_coord(1,1))/A2;

% Length of triangle side
%
L4=sqrt((TRI_coord(2,1)-TRI_coord(1,1))^2+(TRI_coord(2,2)-TRI_coord(1,2))^2);
L5=sqrt((TRI_coord(3,1)-TRI_coord(2,1))^2+(TRI_coord(3,2)-TRI_coord(2,2))^2);
L6=sqrt((TRI_coord(1,1)-TRI_coord(3,1))^2+(TRI_coord(1,2)-TRI_coord(3,2))^2);
L=[L4 L5 L6];

% Cosinus direction of triangle side
C4=(TRI_coord(2,1)-TRI_coord(1,1))/L4;
C5=(TRI_coord(3,1)-TRI_coord(2,1))/L5;
C6=(TRI_coord(1,1)-TRI_coord(3,1))/L6;
C=[C4 C5 C6];
clear C4 C5 C6

%Sinus direction of triangle side
S4=(TRI_coord(2,2)-TRI_coord(1,2))/L4;
S5=(TRI_coord(3,2)-TRI_coord(2,2))/L5;
S6=(TRI_coord(1,2)-TRI_coord(3,2))/L6;
S=[S4 S5 S6];
clear S4 S5 S6
clear L4 L5 L6

