function [Mod_Astiff, Mod_Asload] = ...
         Modify (Astiff, Asload, Neqns, Ifpre, Fixed)
%
%  This function is for modifying element stiffness matrix and
%  element load vector to conform to prescribed displacements
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 16 December 2003
%
%  Input
%  Astiff :  Assembled global stiffness matrix
%  Asload :  Assembled global load vector
%  Neqns  :  Number of equations
%  Ifpre  :  Vector of parameter definining the fixity of nodes
%            0-free; 1-fixed
%  Fixed  :  Vector of prescribed displacements
%
%  Output
%  Mod_Astiff :  Modified global stiffness matrix
%  Mod_Asload :  Modified global load vector
%
Mod_Astiff = Astiff;  clear Astiff;
Mod_Asload = Asload;  clear Asload;
%
%  Modifying fixity index in order to include 
%  prescribed displacements which at the free dofs
%
Nonzero_Ifpre = Nonzero_index (Ifpre, Fixed);
Nonzero_Fixed = find(Fixed);

Mod_Asload(Nonzero_Ifpre,:)=[];
Mod_Astiff(Nonzero_Ifpre,:)=[];
Mod_Asload = Mod_Asload-Mod_Astiff(:,Nonzero_Fixed)*Fixed(Nonzero_Fixed);
Mod_Astiff(:,Nonzero_Ifpre)=[];