function [Db, Ds] = Modps(IMatno, Props)

%  Evaluating the constitutive matrices
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 27 Jan 2006
%
%  Input
%  IMatno:  Material property number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density, coefficient of thermal expansion
%
%  Output
%  Db:  Bending constitutive matrix
%  Ds:  Shearing constitutive matrix
%
Young=Props(IMatno,1);  Poiss=Props(IMatno,2);
Thick=Props(IMatno,3);  G=Young/2/(1+Poiss);
Db = Young*Thick^3/12/(1-Poiss^2)*...
     [1 Poiss 0; Poiss 1 0; 0 0 0.5*(1-Poiss)];
Ds = G*5/6*Thick*[1 0; 0 1];