function  [Node_Moments, Ave_Moments, Node_Shears, Ave_Shears] = ...
           Moment_Shear_ave(Npoin, Lnods, Moments, Shears)

%  [Node_Moments, Ave_Moments, Node_Shears, Ave_Shears] = ...
%   Moment_Shear_ave(Npoin, Lnods, Moments, Shears)
%
%  To calculate the average values of moments and shears 
%  at common nodes
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification: 14 March 2006
%
%  Input
%  Npoin:  Total number of nodal points in the structure
%  Lnods:  Element node numbers listed per each element
%  Moments:  (Mxx Myy Mxy)' at the vertices for each element
%  Shears :  (Qxz Qyz)' at the vertices for each element
%
%  Output
%  Node_Moments: (Mxx Myy Mxy)' at all nodes
%  Ave_Moments:  (Mxx Myy Mxy)' at the vertices for each element
%  Node_Shears:  (Qxz Qyz)' at all nodes
%  Ave_Shears:   (Qxz Qyz)' at the vertices for each element
%

%  Averaging and
%  assigning the averaged values to each element
%
Node_Moments=zeros(3,Npoin);  Node_Shears=zeros(2,Npoin);
Ave_Moments=Moments;  Ave_Shears=Shears;
for Ipoin=1:Npoin
    [I,J]=find(Lnods==Ipoin);
    Node_Moments(:,Ipoin)= mean( Moments(:,3*(I-1)+J), 2);
    Node_Shears(:,Ipoin)= mean( Shears(:,3*(I-1)+J), 2);
    for ii=1:size(I,1)
        Ave_Moments(:, 3*(I(ii)-1)+J(ii) )= Node_Moments(:,Ipoin);
        Ave_Shears(:, 3*(I(ii)-1)+J(ii) )= Node_Shears(:,Ipoin);
    end
end
