function  [Node_Moments, Ave_Moments] = Moment_ave(Npoin, Lnods, Moments)

%  [Node_Moments, Ave_Moments] = Moment_ave(Npoin, Lnods, Moments)
%
%  To calculate the average values of moments at
%  common nodes
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification:
%
%  Input
%  Npoin:  Total number of nodal points in the structure
%  Lnods:  Element node numbers listed per each element
%  Moments:  (Mxx Myy Mxy)' at the vertices for each element
%
%  Output
%  Node_Moments:  Mxx Myy Mxy)' at all nodes
%  Ave_Moments:  (Mxx Myy Mxy)' at the vertices for each element
%

%  Moment averaging and
%  assigning the averaged moments to each element
%
Node_Moments=zeros(3,Npoin);
Ave_Moments=Moments;
for Ipoin=1:Npoin
    [I,J]=find(Lnods==Ipoin);
    Node_Moments(:,Ipoin)= mean( Moments(:,3*(I-1)+J), 2);
    for ii=1:size(I,1)
        Ave_Moments(:, 3*(I(ii)-1)+J(ii) )= Node_Moments(:,Ipoin);
    end
end
