function x = Node2eqns(x1, Neqns)
%
%  Converting the format of x1 to x, a vector sorted by 
%  equation number
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 17 December 2003
%
%  Input
%  x1 :  Data matrix in 'per nodes' format
%  Neqns  :  Number of equations
%
%  Output
%  x :  vector of data, which listed according to equation numbers
%
%  Example
%  x1 = [ 1 1 0; 2 1 0; 3 1 0; 4 1 0]
%  Neqns = 8
%  x --> [1 0 1 0 1 0 1 0 1 0]
Ndofn= size(x1,2)-1;
x=zeros(Neqns,1);
for Ix1 = 1:size(x1,1)
    for Idofn=1:Ndofn
        Ieqns=Ndofn*(x1(Ix1,1)-1)+Idofn;
        x(Ieqns) = x1(Ix1,Idofn+1);
    end    
end
