function Nodes = Nodes_DOI( Ielem, N_layer, TRI)

%  Nodes = Nodes_DOI( Ielem, N_layer, TRI)
%
%  To generate the node numbers in an N_layer
%  influence domain
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 7 September 2005
%  Enhanced:  27 October 2005
%
%  Input
%  Ielem  : index of the current element
%  N_layer:  number of influence layer(s) (1-5)
%  TRI:  matrix of triangular element connectivity, Nelem*3
%
%  Output
%  Nodes:  node numbers in the N_layer influence domain
%
switch N_layer
    case 1
    Nodes = TRI(Ielem,:);
    %
    case 2
    Nodes_1 = TRI(Ielem,:);
    %  Two-layer nodes
    Nodes_2=[];
    for i_node=1:size(Nodes_1,2)
       [I,J]=find(TRI==Nodes_1(1,i_node));
       I(find(I==Ielem),:)=[];
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_2 = [ Nodes_2  Nodes_node];
    end
    Nodes = Del_same( [Nodes_1 Nodes_2] );
    Nodes=sort(Nodes);
    %
    case 3
    Nodes_1 = TRI(Ielem,:);
    %  Two-layer nodes
    Nodes_2=[];
    for i_node=1:size(Nodes_1,2)
       [I,J]=find(TRI==Nodes_1(1,i_node));
       I(find(I==Ielem),:)=[];
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_2 = [ Nodes_2  Nodes_node];
    end
    Nodes_2=Del_same(Nodes_2);
    for i_node=1:size(Nodes_1,2)
       I_first=find(Nodes_2==Nodes_1(1,i_node));
       Nodes_2(:,I_first)=[];
    end
    %  Three-layer nodes
    Nodes_3=[];
    for i_node=1:size(Nodes_2,2)
       [I,J]=find(TRI==Nodes_2(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_3 = [ Nodes_3  Nodes_node];
    end
    Nodes_3=Del_same(Nodes_3);
    Nodes = Del_same( [Nodes_1 Nodes_2 Nodes_3] );
    Nodes=sort(Nodes);
    %
    case 4
    Nodes_1 = TRI(Ielem,:);
    %  Two-layer nodes
    Nodes_2=[];
    for i_node=1:size(Nodes_1,2)
       [I,J]=find(TRI==Nodes_1(1,i_node));
       I(find(I==Ielem),:)=[];
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_2 = [ Nodes_2  Nodes_node];
    end
    Nodes_2=Del_same(Nodes_2);
    for i_node=1:size(Nodes_1,2)
       I_first=find(Nodes_2==Nodes_1(1,i_node));
       Nodes_2(:,I_first)=[];
    end
    %  Three-layer nodes
    Nodes_3=[];
    for i_node=1:size(Nodes_2,2)
       [I,J]=find(TRI==Nodes_2(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_3 = [ Nodes_3  Nodes_node];
    end
    Nodes_3=Del_same(Nodes_3);
    for i_node=1:size(Nodes_2,2)
       I_second=find(Nodes_3==Nodes_2(1,i_node));
       Nodes_3(:,I_second)=[];
    end
    for i_node=1:size(Nodes_1,2)
       I_first=find(Nodes_3==Nodes_1(1,i_node));
       Nodes_3(:,I_first)=[];
    end
    %  Four-layer nodes
    Nodes_4=[];
    for i_node=1:size(Nodes_3,2)
       [I,J]=find(TRI==Nodes_3(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_4 = [ Nodes_4  Nodes_node];
    end
    Nodes_4=Del_same(Nodes_4);
    Nodes=Del_same( [Nodes_1 Nodes_2 Nodes_3 Nodes_4] );
    Nodes=sort(Nodes);
    %
    %
    case 5
    Nodes_1 = TRI(Ielem,:);
    %  Two-layer nodes
    Nodes_2=[];
    for i_node=1:size(Nodes_1,2)
       [I,J]=find(TRI==Nodes_1(1,i_node));
       I(find(I==Ielem),:)=[];
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_2 = [ Nodes_2  Nodes_node];
    end
    Nodes_2=Del_same(Nodes_2);
    for i_node=1:size(Nodes_1,2)
       I_first=find(Nodes_2==Nodes_1(1,i_node));
       Nodes_2(:,I_first)=[];
    end
    %  Three-layer nodes
    Nodes_3=[];
    for i_node=1:size(Nodes_2,2)
       [I,J]=find(TRI==Nodes_2(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_3 = [ Nodes_3  Nodes_node];
    end
    Nodes_3=Del_same(Nodes_3);
    for i_node=1:size(Nodes_2,2)
       I_second=find(Nodes_3==Nodes_2(1,i_node));
       Nodes_3(:,I_second)=[];
    end
    for i_node=1:size(Nodes_1,2)
       I_first=find(Nodes_3==Nodes_1(1,i_node));
       Nodes_3(:,I_first)=[];
    end
    %  Four-layer nodes
    Nodes_4=[];
    for i_node=1:size(Nodes_3,2)
       [I,J]=find(TRI==Nodes_3(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_4 = [ Nodes_4  Nodes_node];
    end
    Nodes_4=Del_same(Nodes_4);
    for i_node=1:size(Nodes_3,2)
       I_second=find(Nodes_4==Nodes_3(1,i_node));
       Nodes_4(:,I_second)=[];
    end
    for i_node=1:size(Nodes_2,2)
       I_first=find(Nodes_4==Nodes_2(1,i_node));
       Nodes_4(:,I_first)=[];
    end
    %  Five-layer nodes
    Nodes_5=[];
    for i_node=1:size(Nodes_4,2)
       [I,J]=find(TRI==Nodes_4(1,i_node));
       Nodes_node=TRI(I,:);
       [M,N] = size(Nodes_node);
       Nodes_node=Nodes_node(1:(M*N));
       Nodes_5 = [ Nodes_5  Nodes_node];
    end
    Nodes_5=Del_same(Nodes_5);
    Nodes=Del_same( [Nodes_1 Nodes_2 Nodes_3 Nodes_4 Nodes_5] );
    Nodes=sort(Nodes);
    %
    %
    otherwise
    error('Wrong number of influence layers! \n');
end

