%
%  PATCH TEST
%  The patch is adapted from MacNeal and Harder (1985)
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 25 May 2006
%  Modifications: 
%

%  Title of the problem:
Project_Title='MacNeal and Harder s Patch Test with Constant Curvature';

%  Control Data
%  1. Ndofn:  Number of degrees of freedom per nodal point
%  2. Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  3. P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  4. N_layer:  The number of influence layer(s) (1-5)
%  5. theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  6.theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%  7. Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  8. Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  9. Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  10. shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  1  1  2  0.5  6  2  0  1];
                %1  2  3  4  5   6   7  8  9  10   
%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
1	0	0
2   0.06    0
3	0.12	0
4	0.18	0
5	0.24	0
6	0	0.03
7	0.06	0.03
8	0.12	0.03
9	0.18	0.03
10	0.24	0.03
11	0	0.06
12	0.06	0.06
13	0.12	0.06
14	0.18	0.06
15	0.24	0.06
16	0	0.09
17	0.06	0.09
18	0.12	0.09
19	0.18	0.09
20	0.24	0.09
21	0	0.12
22	0.06	0.12
23	0.12	0.12
24	0.18	0.12
25	0.24	0.12];
% 
% 1	0	0
% 2   0.03    0
% 3   0.06    0
% 4   0.09    0
% 5	0.12	0
% 6   0.15    0
% 7	0.18	0
% 8   0.21    0
% 9	0.24	0
% 10	0	0.015
% 11   0.03    0.015
% 12   0.06    0.015
% 13   0.09    0.015
% 14	0.12	0.015
% 15   0.15    0.015
% 16	0.18	0.015
% 17   0.21    0.015
% 18	0.24	0.015
% 19	0	0.03
% 20   0.03    0.03
% 21   0.06    0.03
% 22   0.09    0.03
% 23	0.12	0.03
% 24   0.15    0.03
% 25	0.18	0.03
% 26   0.21    0.03
% 27	0.24	0.03
% 28	0	0.045
% 29   0.03    0.045
% 30   0.06    0.045
% 31   0.09    0.045
% 32	0.12	0.045
% 33   0.15    0.045
% 34	0.18	0.045
% 35   0.21    0.045
% 36	0.24	0.045
% 37	0	0.06
% 38   0.03    0.06
% 39   0.06    0.06
% 40   0.09    0.06
% 41	0.12	0.06
% 42   0.15    0.06
% 43	0.18	0.06
% 44   0.21    0.06
% 45	0.24	0.06
% 46	0	0.075
% 47   0.03    0.075
% 48   0.06    0.075
% 49   0.09    0.075
% 50	0.12	0.075
% 51   0.15    0.075
% 52	0.18	0.075
% 53   0.21    0.075
% 54	0.24	0.075
% 55	0	0.09
% 56   0.03    0.09
% 57   0.06    0.09
% 58   0.09    0.09
% 59	0.12	0.09
% 60   0.15    0.09
% 61	0.18	0.09
% 62   0.21    0.09
% 63	0.24	0.09
% 64	0	0.105
% 65   0.03    0.105
% 66   0.06    0.105
% 67   0.09    0.105
% 68	0.12	0.105
% 69   0.15    0.105
% 70	0.18	0.105
% 71   0.21    0.105
% 72	0.24	0.105
% 73	0	0.12
% 74   0.03    0.12
% 75   0.06    0.12
% 76   0.09    0.12
% 77	0.12	0.12
% 78   0.15    0.12
% 79	0.18	0.12
% 80   0.21    0.12
% 71	0.24	0.12
% ];
%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	6
2	1	2	3	7
3	1	3	4	8
4	1	4	5	9
5	1	2	7	6
6	1	3	8	7
7	1	4	9	8
8	1	5	10	9
9	1	6	7	11
10	1	7	8	12
11	1	8	9	13
12	1	9	10	14
13	1	7	12	11
14	1	8	13	12
15  1   9   14  13
16  1   10  15  14
17  1   11  12  16
18  1   12  13  17  
19  1   13  14  18
20  1   14  15  19
21  1   12  17  16
22  1   13  18  17
23  1   14  19  18
24  1   15  20  19
25  1   16  17  21
26  1   17  18  22
27  1   18  19  23
28  1   19  20  24  
29  1   17  22  21
30  1   18  23  22
31  1   19  24  23
32  1   20  25  24
];

% 1	1	1	2	10
% 2	1	2	3	11
% 3	1	3	4	12
% 4	1	4	5	13
% 5	1	5	6	14
% 6	1	6	7	15
% 7	1	7	8	16
% 8	1	8	9	17
% 9	1	2	11	10
% 10	1	3	12	11
% 11	1	4	13	12
% 12	1	5	14	13
% 13	1	6	15	14
% 14	1	7	16	15
% 15  1   8   17  16
% 16  1   9   18  17
% 17  1   10  11  19  
% 18  1   11  12  20
% 19  1   12  13  21
% 20  1   13  14  22
% 21  1   14  15  23
% 22  1   15  16  24
% 23  1   16  17  25
% 24  1   17  18  26
% 25  1   11  20  19
% 26  1   12  21  20
% 27  1   13  22  21  
% 28  1   14  23  22
% 29  1   15  24  23
% 30  1   16  25  24
% 31  1   17  26  25
% 32  1   18  27  26
% 33  1   19  20  28
% 34  1   20  21  29
% 35  1   21  22  30
% 36  1   22  23  31
% 37  1   23  24  32
% 38  1   24  25  33
% 39  1   25  26  34
% 40  1   26  27  35
% 41  1   20  29  28
% 42  1   21  30  29
% 43  1   22  31  30
% 44  1   23  32  31
% 45  1   24  33  32
% 46  1   25  34  33
% 47  1   26  35  34
% 48  1   27  36  35
% 49  1   28  29  37 
% 50  1   29  30  38
% 51  1   30  31  39
% 52  1   31  32  40
% 53  1   32  33  41    
% 54  1   33  34  42
% 55  1   34  35  43  
% 56  1   35  36  44    
% 57  1   29  38  37
% 58  1   30  39  38
% 59  1   31  40  39
% 60  1   32  41  40  
% 61  1   33  42  41
% 62  1   34  43  42
% 63  1   35  44  43
% 64  1   36  45  44
% 65  1   37  38  46  
% 66  1   38  39  47
% 67  1   39  40  48
% 68  1   40  41  49
% 69  1   41  42  50
% 70  1   42  43  51
% 71  1   43  44  52
% 72  1   44  45  53
% 73  1   38  47  46
% 74  1   39  48  47
% 75  1   40  49  48
% 76  1   41  50  49
% 77  1   42  51  50
% 78  1   43  52  51
% 79  1   44  53  52
% 80  1   45  54  53
% 81  1   46  47  55 
% 82  1   47  48  56
% 83  1   48  49  57
% 84  1   49  50  58
% 85  1   50  51  59
% 86  1   51  52  60
% 87  1   52  53  61
% 88  1   53  54  62
% 89  1   47  56  55
% 90  1   48  57  56
% 91  1   49  58  57
% 92  1   50  59  58
% 93  1   51  60  59
% 94  1   52  61  60
% 95  1   53  62  61
% 96  1   54  63  62
% 97  1   55  56  64
% 98  1   56  57  65    
% 99  1   57  58  66
% 100 1   58  59  67
% 101 1   59  60  68
% 102 1   60  61  69
% 103 1   61  62  70
% 104 1   62  63  71
% 105 1   56  65  64
% 106 1   57  66  65
% 107 1   58  67  66
% 108 1   59  68  67
% 109 1   60  69  68
% 110 1   61  70  69
% 111 1   62  71  70
% 112 1   63  72  71
% 113 1   64  65  73  
% 114 1   65  66  74
% 115 1   66  67  75
% 116 1   67  68  76
% 117 1   68  69  77
% 118 1   69  70  78
% 119 1   70  71  79  
% 120 1   71  72  80
% 121 1   65  74  73
% 122 1   66  75  74
% 123 1   67  76  75
% 124 1   68  77  76
% 125 1   69  78  77
% 126 1   70  79  78
% 127 1   71  80  79  
% 128 1   72  81  80];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
% prescribed displacement 
1	1	1	1	0	 0	  0
2	1	1	1	1.80E-06	3.00E-05	-6.00E-05
3	1	1	1	7.20E-06	6.00E-05	-1.20E-04
4	1	1	1	1.62E-05	9.00E-05	-1.80E-04
5	1	1	1	2.88E-05	1.20E-04	-2.40E-04
6	1	1	1	4.50E-07	3.00E-05	-1.50E-05
10	1	1	1	3.285E-05	1.500E-04	-2.550E-04
11	1	1	1	1.800E-06	6.000E-05	-3.000E-05
15	1	1	1	3.78E-05	1.80E-04	-2.70E-04
16	1	1	1	4.05E-06	9.00E-05	-4.50E-05
20	1	1	1	4.365E-05	2.100E-04	-2.850E-04
21	1	1	1	7.200E-06	1.200E-04	-6.000E-05
22	1	1	1	1.260E-05	1.500E-04	-1.200E-04
23	1	1	1	2.160E-05	1.800E-04	-1.800E-04
24	1	1	1	3.420E-05	2.100E-04	-2.400E-04
25	1	1	1	5.040E-05	2.400E-04	-3.000E-04 ];
% 1	1	1	1	0	 0	  0
% 3	1	1	1	1.80E-06	3.00E-05	-6.00E-05
% 5	1	1	1	7.20E-06	6.00E-05	-1.20E-04
% 7	1	1	1	1.62E-05	9.00E-05	-1.80E-04
% 9	1	1	1	2.88E-05	1.20E-04	-2.40E-04
% 19	1	1	1	4.50E-07	3.00E-05	-1.50E-05
% 27	1	1	1	3.285E-05	1.500E-04	-2.550E-04
% 37	1	1	1	1.800E-06	6.000E-05	-3.000E-05
% 45	1	1	1	3.78E-05	1.80E-04	-2.70E-04
% 55	1	1	1	4.05E-06	9.00E-05	-4.50E-05
% 63	1	1	1	4.365E-05	2.100E-04	-2.850E-04
% 73	1	1	1	7.200E-06	1.200E-04	-6.000E-05
% 75	1	1	1	1.260E-05	1.500E-04	-1.200E-04
% 77	1	1	1	2.160E-05	1.800E-04	-1.800E-04
% 79	1	1	1	3.420E-05	2.100E-04	-2.400E-04
% 81	1	1	1	5.040E-05	2.400E-04	-3.000E-04 ];


%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  1E6 0.25 0.001 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:32 ]';
Body_f= [ N_b  zeros(32,1)  zeros(32,1)  zeros(32,1)];
% N_b=[ 1:128 ]';
% Body_f= [ N_b  zeros(128,1)  zeros(128,1)  zeros(128,1)];
%  Traction Force
%  Trac_f:  Applied traction force 
               % sisi 5 10 15 20 25
 Trac_f=[ ];              
% Trac_f=[ 5  10   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         10  15   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         15  20   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         20  25   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0]; % as moment
% 
% Trac_f=[ 5  10   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         10  15   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         15  20   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         20  25   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0]; %as stress
    
    
 % sisi 21 22 23 24 25
% Trac_f=[25  24   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         24  23   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         23  22   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         22  21   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7]; % as moment
%
%  Trac_f=[25  24   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         24  23   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         23  22   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         22  21   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4]; %as stress


%  Exact Moments and Shears
%  Mx=My=-10/9*1E-7 
%  Mxy=-1/3*1E-7  
%  Qx=Qy=0


%  Exact Stress
%  Sigmx=Sigmy=-10/9*1E-7 / Thick  =  -10/9*1E-4