%
%  PATCH TEST
%  The patch is adapted from MacNeal and Harder (1985)
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 25 May 2006
%  Modifications: 
%

%  Title of the problem:
Project_Title='MacNeal and Harder s Patch Test with Constant Curvature';

%  Control Data
%  1. Ndofn:  Number of degrees of freedom per nodal point
%  2. Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  3. P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  4. N_layer:  The number of influence layer(s) (1-5)
%  5. theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  6.theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%  7. Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  8. Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  9. Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  10. shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  3  3  2  0.5  6  2  1  1];
                %1  2  3  4  5   6   7  8  9  10   
%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
% 1	0	0
% 2   0.03    0
% 3	0.06	0
% 4   0.09    0
% 5	0.12	0
% 6   0.15    0
% 7	0.18	0
% 8   0.21    0
% 9	0.24	0
% 10   0   0.015
% 11  0.02    0.01
% 12  0.05    0.01
% 13  0.085   0.0075
% 14  0.115   0.0075
% 15  0.15    0.015
% 16  0.18    0.015
% 17  0.21    0.015
% 18  0.24    0.015
% 19  0       0.03
% 20  0.02    0.025
% 21	0.04	0.02
% 22  0.06    0.025
% 23	0.11	0.015
% 24  0.145   0.0225
% 25	0.18	0.03
% 26  0.21    0.03
% 27	0.24	0.03
% 28  0       0.045
% 29  0.02    0.04
% 30  0.05    0.035
% 31  0.085   0.0325
% 32  0.115   0.0375
% 33  0.14    0.035
% 34  0.175   0.0425
% 35  0.21    0.045
% 36  0.24    0.045
% 37	0       0.06
% 38  0.03    0.055
% 39	0.06	0.05
% 40  0.09    0.055
% 41	0.12	0.06
% 42  0.145   0.0575
% 43	0.17	0.055
% 44  0.205   0.0575
% 45	0.24	0.06
% 46  0       0.075
% 47  0.03    0.07
% 48  0.07    0.065
% 49  0.1     0.07
% 50  0.12    0.07
% 51  0.14    0.07
% 52  0.165   0.0675
% 53  0.205   0.0725
% 54  0.24    0.075
% 55	0       0.09
% 56  0.06    0.085
% 57	0.08	0.08
% 58  0.1     0.08
% 59	0.12	0.08
% 60  0.14    0.08
% 61	0.16	0.08
% 62  0.2     0.085
% 63	0.24	0.09
% 64  0       0.105
% 65  0.03    0.105
% 66  0.07    0.1
% 67  0.1     0.1
% 68  0.12    0.1
% 69  0.14    0.1
% 70  0.17    0.1
% 71  0.21    0.105
% 72  0.24    0.105
% 73	0       0.12
% 74  0.03    0.12
% 75	0.06	0.12
% 76  0.09    0.12
% 77	0.12	0.12
% 78  0.15    0.12
% 79	0.18	0.12
% 80  0.21    0.12
% 81	0.24	0.12];

1	0	0
2   0.06    0
3	0.12	0
4	0.18	0
5	0.24	0
6	0	0.03
7	0.04	0.02
8	0.11	0.015
9	0.18	0.03
10	0.24	0.03
11	0	0.06
12	0.06	0.05
13	0.12	0.06
14	0.17	0.055
15	0.24	0.06
16	0	0.09
17	0.08	0.08
18	0.12	0.08
19	0.16	0.08
20	0.24	0.09
21	0	0.12
22	0.06	0.12
23	0.12	0.12
24	0.18	0.12
25	0.24	0.12];
%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
% 1	1	1	2	11
% 2	1	2	3	12
% 3	1	3	4	13
% 4	1	4	5	14
% 5	1	5	6	15
% 6	1	6	7	16
% 7	1	7	8	16
% 8	1	8	9	17
% 9	1	1	11	10
% 10	1	2	12	11
% 11	1	3	22	12
% 12	1	3	13	22
% 13	1	4	14	13
% 14	1	5	15	14
% 15  1   6   16  15
% 16  1   8   17  16
% 17  1   9   18  17
% 18  1   10  11  20  
% 19  1   11  12  21
% 20  1   12  22  30
% 21  1   13  31  22
% 22  1   13  14  23
% 23  1   14  15  24
% 24  1   15  16  25
% 25  1   16  17  25
% 26  1   17  18  26
% 27  1   10  20  19
% 28  1   11  21  20  
% 29  1   12  30  21
% 30  1   22  39  30
% 31  1   22  31  39
% 32  1   13  23  31
% 33  1   23  14  24
% 34  1   15  25  24
% 35  1   17  26  25
% 36  1   18  27  26
% 37  1   19  20  28
% 38  1   20  21  29
% 39  1   21  30  29
% 40  1   30  39  38
% 41  1   31  40  39
% 42  1   31  23  32
% 43  1   23  33  32
% 44  1   23  24  33
% 45  1   24  34  33
% 46  1   24  25  34
% 47  1   25  35  34
% 48  1   25  26  35
% 49  1   26  36  35 
% 50  1   26  27  36
% 51  1   20  29  28
% 52  1   28  29  37
% 53  1   29  38  37
% 54  1   29  30  38
% 55  1   31  32  40  
% 56  1   32  41  40
% 57  1   32  42  41
% 58  1   32  33  42
% 59  1   33  43  42
% 60  1   33  34  43
% 61  1   34  44  43
% 62  1   34  35  44
% 63  1   35  45  44
% 64  1   35  36  45
% 65  1   37  38  46
% 66  1   38  47  46
% 67  1   38  39  47
% 68  1   39  56  47
% 69  1   39  48  56
% 70  1   39  40  48
% 71  1   40  49  48
% 72  1   40  41  49
% 73  1   41  50  49
% 74  1   41  51  50
% 75  1   41  42  51
% 76  1   42  52  51
% 77  1   43  52  42
% 78  1   43  53  52
% 79  1   44  53  43
% 80  1   44  54  53
% 81  1   44  45  54 
% 82  1   46  47  55 
% 83  1   47  65  55
% 84  1   55  65  64
% 85  1   47  56  65
% 86  1   48  66  56
% 87  1   48  57  66
% 88  1   48  49  57
% 89  1   49  58  57
% 90  1   49  50  58  
% 91  1   50  59  58
% 92  1   50  60  59
% 93  1   51  60  50
% 94  1   51  61  60
% 95  1   51  52  61  
% 96  1   52  62  61
% 97  1   52  53  62
% 98  1   53  63  62
% 99  1   53  54  63
% 100 1   64  65  74
% 101 1   64  74  73
% 102 1   65  75  74
% 103 1   65  56  75
% 104 1   56  66  75
% 105 1   66  76  75
% 106 1   66  67  76
% 107 1   57  67  66
% 108 1   57  58  67
% 109 1   58  68  67  
% 110 1   67  77  76  
% 111 1   67  68  77
% 112 1   58  59  68
% 113 1   59  60  68
% 114 1   60  69  68
% 115 1   60  61  69  
% 116 1   61  70  69
% 117 1   62  70  61
% 118 1   62  71  70  
% 119 1   62  63  71
% 120 1   63  72  71
% 121 1   68  69  77
% 122 1   69  78  77
% 123 1   70  78  69
% 124 1   70  79  78
% 125 1   70  71  79
% 126 1   71  80  79
% 127 1   71  72  80  
% 128 1   72  81  80];
% % % % 
% 1	1	1	2	7
% 2	1	2	3	8
% 3	1	3	4	9
% 4	1	4	5	9
% 5	1	5	10	9
% 6	1	7	6	1
% 7	1	2	12	7
% 8	1	8	12	2
% 9	1	3	9	8
% 10	1	7	11	6
% 11	1	7	12	11
% 12	1	8	13	12
% 13	1	8	14	13
% 14	1	8	9	14
% 15  1   9   15  14
% 16  1   9   10  15
% 17  1   11  12  16
% 18  1   12  13  17  
% 19  1   13  14  19
% 20  1   14  15  20
% 21  1   16  12  22
% 22  1   12  17  22
% 23  1   17  13  18
% 24  1   13  19  18
% 25  1   14  20  19
% 26  1   16  22  21
% 27  1   22  17  23
% 28  1   17  18  23  
% 29  1   18  19  23
% 30  1   23  19  24
% 31  1   19  20  24
% 32  1   20  25  24
];
%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
% Patch81 manual
% 1	1	1	1	0	0	0
% 2	1	1	1	4.50000E-07	1.500E-05	-3.000E-05
% 3	1	1	1	1.80000E-06	3.000E-05	-6.000E-05
% 4	1	1	1	4.05000E-06	4.500E-05	-9.000E-05
% 5	1	1	1	7.20000E-06	6.000E-05	-1.200E-04
% 6	1	1	1	1.12500E-05	7.500E-05	-1.500E-04
% 7	1	1	1	1.62000E-05	9.000E-05	-1.800E-04
% 8	1	1	1	2.20500E-05	1.050E-04	-2.100E-04
% 9	1	1	1	2.88000E-05	1.200E-04	-2.400E-04
% 10  1   1   1	1.12500E-07	1.500E-05	-7.500E-06
% 19	1	1	1	4.50E-07	3.00E-05	-1.50E-05 
% 18  1   1   1	3.07125E-05	1.350E-04	-2.475E-04
% 27	1	1	1	3.28500E-05	1.500E-04	-2.550E-04
% 28  1   1   1	1.01250E-06	4.500E-05	-2.250E-05
% 37	1	1	1	1.80000E-06	6.000E-05	-3.000E-05
% 36  1   1   1	3.52125E-05	1.650E-04	-2.625E-04
% 45	1	1	1	3.78000E-05	1.800E-04	-2.700E-04
% 46  1   1   1	2.81250E-06	7.500E-05	-3.750E-05
% 55	1	1	1	4.05000E-06	9.000E-05	-4.500E-05
% 54  1   1   1	4.06125E-05	1.950E-04	-2.775E-04
% 63	1	1	1	4.36500E-05	2.100E-04	-2.850E-04
% 72  1   1   1	4.69125E-05	2.250E-04	-2.925E-04
% 64  1   1   1	5.51250E-06	1.050E-04	-5.250E-05
% 73	1	1	1	7.20000E-06	1.200E-04	-6.000E-05
% 74  1   1   1	9.45000E-06	1.350E-04	-9.000E-05
% 75	1	1	1	1.26000E-05	1.500E-04	-1.200E-04
% 76	1	1	1	1.66500E-05	1.650E-04	-1.500E-04
% 77	1	1	1	2.16000E-05	1.800E-04	-1.800E-04
% 78	1	1	1	2.74500E-05	1.950E-04	-2.100E-04
% 79	1	1	1	3.42000E-05	2.100E-04	-2.400E-04
% 80	1	1	1	4.18500E-05	2.250E-04	-2.700E-04
% 81	1	1	1	5.04000E-05	2.400E-04	-3.000E-04 ];

% prescribed displacement 
% 1	1	1	1	0	 0	  0
% 2	1	1	1	1.80E-06	3.00E-05	-6.00E-05
% 3	1	1	1	7.20E-06	6.00E-05	-1.20E-04
% 4	1	1	1	1.62E-05	9.00E-05	-1.80E-04
% 5	1	1	1	2.88E-05	1.20E-04	-2.40E-04
% 6	1	1	1	4.50E-07	3.00E-05	-1.50E-05
% 10	1	1	1	3.285E-05	1.500E-04	-2.550E-04
% 11	1	1	1	1.800E-06	6.000E-05	-3.000E-05
% 15	1	1	1	3.78E-05	1.80E-04	-2.70E-04
% 16	1	1	1	4.05E-06	9.00E-05	-4.50E-05
% 20	1	1	1	4.365E-05	2.100E-04	-2.850E-04
% 21	1	1	1	7.200E-06	1.200E-04	-6.000E-05
% 22	1	1	1	1.260E-05	1.500E-04	-1.200E-04
% 23	1	1	1	2.160E-05	1.800E-04	-1.800E-04
% 24	1	1	1	3.420E-05	2.100E-04	-2.400E-04
% 25	1	1	1	5.040E-05	2.400E-04	-3.000E-04 ];

%prescribe all node displacement
1	1	1	1	0	0	0
2	1	1	1	0.0000018	0.00003	-0.00006
3	1	1	1	0.0000072	0.00006	-0.00012
4	1	1	1	0.0000162	0.00009	-0.00018
5	1	1	1	0.0000288	0.00012	-0.00024
6	1	1	1	0.00000045	0.00003	-0.000015
7	0	0	0	0.0000014	0.00004	-0.00005
8	0	0	0	6.9875E-06	0.00007	-0.0001175
9	0	0	0	0.00001935	0.00012	-0.000195
10	1	1	1	0.00003285	0.00015	-0.000255
11	1	1	1	0.0000018	0.00006	-0.00003
12	0	0	0	0.00000455	0.00008	-0.000085
13	0	0	0	0.0000126	0.00012	-0.00015
14	0	0	0	2.06375E-05	0.00014	-0.0001975
15	1	1	1	0.0000378	0.00018	-0.00027
16	1	1	1	0.00000405	0.00009	-0.000045
17	0	0	0	0.0000096	0.00012	-0.00012
18	0	0	0	0.0000152	0.00014	-0.00016
19	0	0	0	0.0000224	0.00016	-0.0002
20	1	1	1	0.00004365	0.00021	-0.000285
21	1	1	1	0.0000072	0.00012	-0.00006
22	1	1	1	0.0000126	0.00015	-0.00012
23	1	1	1	0.0000216	0.00018	-0.00018
24	1	1	1	0.0000342	0.00021	-0.00024
25	1	1	1	0.0000504	0.00024	-0.0003
];



% % sisi kiri
% 1	1	1	0	0	0	0
% 6	1	1	0	0   0   0   
% 11	1	1	0	0   0   0
% 16	1	1	0	0   0   0
% 21	1	1	0	0   0   0];
% 
% % % sisi bawah
% 1	1	0	1	0	0	0
% 2	1	0	1	0   0   0   
% 3	1	0	1	0   0   0
% 4	1	0	1	0   0   0
% 5	1	0	1	0   0   0];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  1E6 0.25 0.001 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:32 ]';
Body_f= [ N_b  zeros(32,1)  zeros(32,1)  zeros(32,1)];
% N_b=[ 1:128 ]';
% Body_f= [ N_b  zeros(128,1)  zeros(128,1)  zeros(128,1)];
%  Traction Force
%  Trac_f:  Applied traction force 
               % sisi 5 10 15 20 25
 Trac_f=[ ];              
% Trac_f=[ 5  10   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         10  15   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         15  20   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0
%         20  25   -10/9*1E-7   0   -10/9*1E-7   0  -10/9*1E-7   0]; % as moment
% 
% Trac_f=[ 5  10   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         10  15   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         15  20   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0
%         20  25   -10/9*1E-4   0   -10/9*1E-4   0  -10/9*1E-4   0]; %as stress
    
    
 % sisi 21 22 23 24 25
% Trac_f=[25  24   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         24  23   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         23  22   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7
%         22  21   0   10/9*1E-7   0   10/9*1E-7   0  10/9*1E-7]; % as moment
%
%  Trac_f=[25  24   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         24  23   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         23  22   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4
%         22  21   0   10/9*1E-4   0   10/9*1E-4   0  10/9*1E-4]; %as stress


%  Exact Moments and Shears
%  Mx=My=-10/9*1E-7 
%  Mxy=-1/3*1E-7  
%  Qx=Qy=0


%  Exact Stress
%  Sigmx=Sigmy=-10/9*1E-7 / Thick  =  -10/9*1E-4