%
%  PATCH TEST
%  The patch is adapted from MacNeal and Harder (1985)
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 25 May 2006
%  Modifications: 
%

%  Title of the problem:
Project_Title='MacNeal and Harder s Patch Test with Constant Curvature';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  3  3  2  0.5  6  2  1  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
1	0	0
2	0.06	0
3	0.12	0
4	0.18	0
5	0.24	0
6	0	0.03
7	0.04	0.02
8	0.11	0.015
9	0.18	0.03
10	0.24	0.03
11	0	0.06
12	0.06	0.05
13	0.12	0.06
14	0.17	0.055
15	0.24	0.06
16	0	0.09
17	0.08	0.08
18	0.12	0.08
19	0.16	0.08
20	0.24	0.09
21	0	0.12
22	0.06	0.12
23	0.12	0.12
24	0.18	0.12
25	0.24	0.12];

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[ ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	1	1	0	 0	  0
2	1	1	1	1.80E-06	3.00E-05	-6.00E-05
3	1	1	1	7.20E-06	6.00E-05	-1.20E-04
4	1	1	1	1.62E-05	9.00E-05	-1.80E-04
5	1	1	1	2.88E-05	1.20E-04	-2.40E-04
6	1	1	1	4.50E-07	3.00E-05	-1.50E-05
10	1	1	1	3.285E-05	1.500E-04	-2.550E-04
11	1	1	1	1.800E-06	6.000E-05	-3.000E-05
15	1	1	1	3.78E-05	1.80E-04	-2.70E-04
16	1	1	1	4.05E-06	9.00E-05	-4.50E-05
20	1	1	1	4.365E-05	2.100E-04	-2.850E-04
21	1	1	1	7.200E-06	1.200E-04	-6.000E-05
22	1	1	1	1.260E-05	1.500E-04	-1.200E-04
23	1	1	1	2.160E-05	1.800E-04	-1.800E-04
24	1	1	1	3.420E-05	2.100E-04	-2.400E-04
25	1	1	1	5.040E-05	2.400E-04	-3.000E-04 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  1E6 0.25 0.001 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:32 ]';
Body_f= [ N_b  zeros(32,1)  zeros(32,1)  zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Exact Moments and Shears
%  Mx=My=-10/9*1E-7
%  Mxy=-1/3*1E-7
%  Qx=Qy=0
%