%
%  PATCH TEST 2
%  The patch is adapted from MacNeal and Harder (1985)
%  Constant 'shear strain x'
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 28 May 2006
%  Modifications: 
%

%  Title of the problem:
Project_Title='MacNeal and Harder s Patch Test with Constant Shear Strain x';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  1  4  4  2  0  6  2  1  2];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=[
1	0	0
2	0.06	0
3	0.12	0
4	0.18	0
5	0.24	0
6	0	0.03
7	0.04	0.02
8	0.11	0.015
9	0.18	0.03
10	0.24	0.03
11	0	0.06
12	0.06	0.05
13	0.12	0.06
14	0.17	0.055
15	0.24	0.06
16	0	0.09
17	0.08	0.08
18	0.12	0.08
19	0.16	0.08
20	0.24	0.09
21	0	0.12
22	0.06	0.12
23	0.12	0.12
24	0.18	0.12
25	0.24	0.12];

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[ ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	1	1	0	0	0
2	1	1	1	0.001584	0	-0.0504
3	1	1	1	0.00576	    0	-0.0864
4	1	1	1	0.011664	0	-0.108
5	1	1	1	0.018432	0	-0.1152
6	1	1	1	0	0	0
10	1	1	1	0.018432	0	-0.1152
11	1	1	1	0	0	0
15	1	1	1	0.018432	0	-0.1152
16	1	1	1	0	0	0
20	1	1	1	0.018432	0	-0.1152
21	1	1	1	0	0	0
22	1	1	1	0.001584	0	-0.0504
23	1	1	1	0.00576	    0	-0.0864
24	1	1	1	0.011664	0	-0.108
25	1	1	1	0.018432	0	-0.1152 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  1E6 0 0.001 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:32 ]';
Body_f= [ N_b  zeros(32,1)  zeros(32,1)  zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Exact Moments and Shears
%  Mx=1/3*1E-3*(x-0.24);  My=Mxy=0
%  Qx=1/3*1E-3;  Qy=0
%