    %
%  INPUT DATA FORMAT FOR REISSNER-MINDLIN PLATE
%
%  Written by Sebastian
%  Petra Christian University, 20 Maret 2020
%

%  Title of the problem:
Project_Title='RM Plate Element FEM Project Mesh A';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13) kalo satu sama aja
%          g ada integration
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
Control_cards = [3  2  1  1  2  0.5  3  2  0  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = [
    1   0   0
    2   12.5  0
    3   25  0
    4   37.5   0
    5   50   0
    6   0  12.5
    7   12.5  12.5
    8   25  12.5
    9   37.5  12.5
    10  50  12.5
    11  0  25
    12  12.5  25
    13  25  25
    14  37.5  25
    15  50  25
    16  0  37.5
    17  12.5  37.5
    18  25  37.5
    19  37.5  37.5
    20  50  37.5
    21  0  50
    22  12.5  50
    23  25  50
    24  37.5  50
    25  50  50]; % mm


%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	7
2	1	1	7	6
3	1	2	3	8
4	1	2	8	7
5   1   3   4   9
6   1   3   9   8
7   1   4   5   10
8   1   4   10  9
9   1   6   7   12
10  1   6   12  11
11  1   7   8   13
12  1   7   13  12
13  1   8   9   14
14  1   8   14  13
15  1   9   10  15
16  1   9   15  14
17  1   11  12  17
18  1   11  17  16
19  1   12  13  18
20  1   12  18  17
21  1   13  14  19
22  1   13  19  18
23  1   14  15  20
24  1   14  20  19
25  1   16  17  22
26  1   16  22  21
27  1   17  18  23
28  1   17  23  22
29  1   18  19  24
30  1   18  24  23
31  1   19  20  25
32  1   19  25  24];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements w bx by
Restrained_cards=[ 
 1  0  1  1   0  0  0 
%  26  0  0  0   0  0  0
 2  0  1  0   0  0  0
%  29  0  0  0   0  0  0
 3  0  1  0   0  0  0
%  32  0  0  0   0  0  0
 4  0  1  0   0  0  0 
%  35  0  0  0   0  0  0
 5  1  1  1   0  0  0
%  38  1  0  0   0  0  0
 10  1  1  1   0  0  0
%  51  1  0  0   0  0  0
 15  1  1  1   0  0  0
%  64  1  0  0   0  0  0
 20  1  1  1   0  0  0
%  77  1  0  0   0  0  0
 25  1  1  1   0  0  0
%  81  1  0  0   0  0  0
 24  1  1  1   0  0  0
%  80  1  0  0   0  0  0
 23  1  1  1   0  0  0
%  79  1  0  0   0  0  0
 22  1  1  1   0  0  0
%  78  1  0  0   0  0  0
 21  1  1  1   0  0  0
%  67  0  0  0   0  0  0
 16  0  0  1   0  0  0
%  54  0  0  0   0  0  0
 11  0  0  1   0  0  0
%  41  0  0  0   0  0  0
 6  0  0  1   0  0  0];
%  28  0  0  0   0  0  0];


%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 20];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:32]';
Body_f= [N_b  1E-06*ones(32,1)   zeros(32,1)   zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

% h plate
% 20
% 10
% 1
% 0.1
% 0.01
% 0.001

