    %
%  INPUT DATA FORMAT FOR REISSNER-MINDLIN PLATE
%
%  Written by Sebastian
%  Petra Christian University, 20 Maret 2020
%

%  Title of the problem:
Project_Title='RM Plate Element FEM Project Mesh A';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13) kalo satu sama aja
%          g ada integration
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
Control_cards = [3  13  0];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = [
    1   0   0
    2   12.5  0
    3   25  0
    4   37.5   0
    5   50   0
    6   0  12.5
    7   12.5  12.5
    8   25  12.5
    9   37.5  12.5
    10  50  12.5
    11  0  25
    12  12.5  25
    13  25  25
    14  37.5  25
    15  50  25
    16  0  37.5
    17  12.5  37.5
    18  25  37.5
    19  37.5  37.5
    20  50  37.5
    21  0  50
    22  12.5  50
    23  25  50
    24  37.5  50
    25  50  50]; % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	6
2	1	2	6	7
3	1	2	3	7
4	1	3	7	8
5   1   3   4   8
6   1   4   8   9
7   1   4   5   9
8   1   5   9   10
9   1   6   7   11
10  1   7   11  12
11  1   7   8   12
12  1   8   12  13
13  1   8   9   13
14  1   9   13  14
15  1   9   10  14
16  1   10   14  15
17  1   11  12  16
18  1   12  16  17
19  1   12  13  17
20  1   13  17  18
21  1   13  14  18
22  1   14  18  19
23  1   14  15  19
24  1   15  19  20
25  1   16  17  21
26  1   17  21  22
27  1   17  18  22
28  1   18  22  23
29  1   18  19  23
30  1   19  23  24
31  1   19  20  24
32  1   20  24  25];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements w bx by
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 3  0  1  0   0  0  0
 4  0  1  0   0  0  0 
 5  1  1  1   0  0  0
 10  1  1  1   0  0  0
 15  1  1  1   0  0  0
 20  1  1  1   0  0  0
 25  1  1  1   0  0  0
 24  1  1  1   0  0  0
 23  1  1  1   0  0  0
 22  1  1  1   0  0  0
 21  1  1  1   0  0  0
 16  0  0  1   0  0  0
 11  0  0  1   0  0  0
 6  0  0  1   0  0  0];

CoordCont=[1 2 3 4 5 10 15 20 25 24 23 22 21 16 11 6 1];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2*1E+06 0.3 10];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:32]';
Body_f= [N_b  1E-06*ones(32,1)   zeros(32,1)   zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

% h plate
% 10
% 5
% 0.5
% 0.05
% 0.005
% 0.0005

