function Plot_Ave_Moments (Lnods, Coord, Nelem, Sigma)

%  Plot_Ave_Moments (Lnods, Coord, Nelem, Sigma)
%
%  To plot moment contours in the undeformed shape
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 29 December 2003
%  Modification: 17 March 2004, 30 August, 9 September 2005
%                13, 16 March 2006 
%
%  Input
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the nodes
%  Nelem:  Total number of elements in the structure
%  Sigma:  Matrix of the order (3 x N_Sigma)
%          containing the bending moments in x and y directions
%          and the twisting moments
%
%  Output
%  Figure(6): 1. Contour of the bending moment in the x-direction 
%             2. Contour of the bending moment in the y-direction
%             3. Contour of the twisting moment
%
N_Sigma=size(Sigma,2);
n=N_Sigma/Nelem;
%  Plotting bending moment in the x-direction
figure(6); clf;
set(gcf,'renderer','zbuffer')
subplot(2,2,1);
hold on;
for Ielem=1:Nelem
    X=Coord(Lnods(Ielem,:),1);
    Y=Coord(Lnods(Ielem,:),2);
    C=Sigma(1,(n*Ielem-(n-1)):(n*Ielem));
    fill(X,Y,C');
end
colorbar;
hold off
axis('equal');
title('Bending moment in the x-direction');

%  Plotting bending moment in the y-direction
%figure(4);
%clf;
subplot(2,2,2);
hold on;
for Ielem=1:Nelem
    X=Coord(Lnods(Ielem,:),1);
    Y=Coord(Lnods(Ielem,:),2);
    C=Sigma(2,(n*Ielem-(n-1)):(n*Ielem));
    fill(X,Y,C');
end
colorbar;
hold off
axis('equal');
title('Bending moment in the y-direction');
 
%  Plotting twisting moment
%figure(5);
%clf;
subplot(2,2,3);
hold on;
for Ielem=1:Nelem
    X=Coord(Lnods(Ielem,:),1);
    Y=Coord(Lnods(Ielem,:),2);
    C=Sigma(3,(n*Ielem-(n-1)):(n*Ielem));
    fill(X,Y,C');
end
colorbar;
hold off
axis('equal');
title('Twisting moment');
