function Plot_Deform (Lnods, Coord, Npoin, Xdisp, Ndofn)

%  Plot_Deform (Lnods, Coord, Nelem, Xdisp)
%
%  To plot deflection and rotation contours
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 16 March 2006
%  Modification: 
%
%  Input
%  Lnods:  Element node numbers listed per each element,Y
%  Coord:  Coordinate of the nodeY
%  Npoin:  Total number of nodal points in the structure
%  Xdisp:  Nodal displacement vectorY
%  Ndofn:  Number of degrees of freedom per nodal pointY
%
%  Output
%  Figure(4): 1. Contour of the deflection
%             2. Contour of the rotation about x coordinate
%             3. Contour of the rotation about y coordinate
%

X=Coord(:,1);  Y=Coord(:,2);
Nonzero_x= (1:size(Xdisp,1))';
Xdisp1 = Eqns2node(Xdisp, Ndofn, Nonzero_x);
w= Xdisp1(:,2);
theta_x= Xdisp1(:,3);  theta_y= Xdisp1(:,4);

%  Plotting contour of the deflection
figure(4); clf;
set(gcf,'renderer','zbuffer')
subplot(2,2,1);
trisurf(Lnods,X,Y,w)
title(['Deflection'] );
% xlabel('x');  ylabel('y');
axis('equal');
shading interp
colorbar
view(2)
hold on
triplot(Lnods,X,Y,'k')
hold off

%  Plotting contour of the rotation about x coordinate
%figure(4); clf;
subplot(2,2,3);
trisurf(Lnods,X,Y,theta_x)
title(['Rotation about x coordinate'] );
% xlabel('x');  ylabel('y');
axis('equal');
shading interp
colorbar
view(2)
hold on
triplot(Lnods,X,Y,'k')
hold off

%  Plotting contour of the rotation about y coordinate
%figure(4); clf;
subplot(2,2,4);
trisurf(Lnods,X,Y,theta_y)
title(['Rotation about y coordinate'] );
% xlabel('x');  ylabel('y');
axis('equal');
shading interp
colorbar
view(2)
hold on
triplot(Lnods,X,Y,'k')
hold off
