function Plot_Deform3D (Project_Title, Lnods, Coord, Npoin, Xdisp, Ndofn)

%  Plot_Deform3D (Project_Title, Lnods, Coord, Npoin, Xdisp, Ndofn)
% 
%  Plotting the deformed shape of a plate bending in 3D space
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 16 March 2006
%  Last modification:
%
%  Input
%  Project_Title
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the node
%  Npoin:  Total number of nodal points in the structure
%  Xdisp:  Nodal displacement vector
%  Ndofn:  Number of degrees of freedom per nodal point
%
%  Output
%  A figure of the deformed plate in 3D space
%
figure(3); clf;
X=Coord(:,1);  Y=Coord(:,2);
Nonzero_x= (1:size(Xdisp,1))';
Xdisp1 = Eqns2node(Xdisp, Ndofn, Nonzero_x);
w= Xdisp1(:,2);
% shading interp
trisurf(Lnods,X,Y,w)
title(Project_Title);
xlabel('X axis');  ylabel('Y axis');
zlabel('w');
view(-30,60)
colormap( [(0.66:0.02:0.96)' (0.66:0.02:0.96)' (0.66:0.02:0.96)'] )
grid on

%  Put node numbers
hold on;
S_num=max( max(abs(Coord)) )*0.01;
if max(max(w)) > 0
   Sw_num= max( max(abs(w)) )*0.07;
else
   Sw_num= -1*max( max(abs(w)) )*0.07;
end
Ipoin=(1:Npoin)';
text(X+S_num, Y+S_num , w-Sw_num, num2str(Ipoin));  
hold off
