function Plot_Shears (Lnods, Coord, Nelem, Sigma)

%  Plot_Shears (Lnods, Coord, Nelem, Sigma)
%
%  To plot shear force contours in the undeformed shape
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 29 December 2003
%  Modification: 17 March 2004, 30 August, 9 September 2005
%                13, 16 March 2006
%
%  Input
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the nodes
%  Nelem:  Total number of elements in the structure
%  Sigma:  Matrix of the order (2 x N_Sigma)
%          containing the shear forces at x and y planes
%
%  Output
%  Figure(7): 1. Contour of the shear force at x-planes
%             2. Contour of the shear force at y-planes
%
N_Sigma=size(Sigma,2);
n=N_Sigma/Nelem;
%  Plotting shear force at x-planes
figure(7); clf;
set(gcf,'renderer','zbuffer')
subplot(1,2,1);
hold on;
for Ielem=1:Nelem
    X=Coord(Lnods(Ielem,:),1);
    Y=Coord(Lnods(Ielem,:),2);
    C=Sigma(1,(n*Ielem-(n-1)):(n*Ielem));
    fill(X,Y,C');
end
colorbar;
hold off
axis('equal');
title('Shear force at x planes');

%  Plotting shear force at y-planes
%figure(4); clf;
subplot(1,2,2);
hold on;
for Ielem=1:Nelem
    X=Coord(Lnods(Ielem,:),1);
    Y=Coord(Lnods(Ielem,:),2);
    C=Sigma(2,(n*Ielem-(n-1)):(n*Ielem));
    fill(X,Y,C');
end
colorbar;
hold off
axis('equal');
title('Shear force at y planes');
 