%
%  Program for computing the relative L2 norm of displacement error
%  (and relative norm of strain energy error)--- future extention
%  for the case of the patch test under constant shear
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 1 September 2005
%  Adapted from Rel_Error.m in CST Ver. 2 and in K-FE, 2D Elastostatics
%  Last modification: 12 February 2007
%
% clear;  tic;
% Input_file_name='Beam2_out';
% eval(['load ', Input_file_name])
%
tic
Nsamp=13
%
El_area=zeros(Nelem,1);
Exact_norm2=zeros(Nelem,1);
Disp_norm2=zeros(Nelem,1);
fprintf('\n   Computing the error norms ... \n ')
%
for Ielem=1:Nelem
    %
    %  Picking sampling points and their weights
    %
    TRI_coord=Coord(TRI(Ielem,:),:);
    xt1=TRI_coord(1,:)';  xt2=TRI_coord(2,:)';  xt3=TRI_coord(3,:)';
    [xip, vip] = Tri_integral (xt1,xt2,xt3, Nsamp);
    clear xt1 xt2 xt3
    %
    %  Computing exact solutions
    %
    x=xip(1,:);  y=xip(2,:);
    w= 1E-6*(x + y)/2;
    theta_x= -0.5E-6*ones(1,Nsamp);
    theta_y= 0.5E-6*ones(1,Nsamp);
    w=w';  theta_x=theta_x';  theta_y=theta_y';
    clear x y
    %
    %  Computing approximate solutions at the sampling points
    %
        %  Nodal coordinates in the influence domain
    n_Nodes_I = n_Nodes(Ielem,1);
    Nodes_I = Nodes{ Ielem,: };
    Coord_DOI=Coord(Nodes_I,:);
    theta_I = theta(Ielem,1);
    d_max = Max_Distance( Coord_DOI);
        %  Kriging shape functions
    PHI = Kriging_shapef( Coord_DOI, theta_I, d_max, P_order, xip', Cor_type);
    clear Coord_DOI theta_I d_max
        %  Identify the displacements of the element nodal points
    I_dof = Global_dof (Nodes_I, n_Nodes_I, Ndofn);
    Eldisp=Xdisp(I_dof,:);
        %
    Ndofe=Ndofn*n_Nodes_I;
    w_app = PHI*Eldisp(1:3:(Ndofe-2));
    theta_x_app = PHI*Eldisp(2:3:(Ndofe-1));
    theta_y_app = PHI*Eldisp(3:3:Ndofe);
    clear  Nodes_I  n_Nodes_I  I_dof Eldisp Ndofe
    %
    %  Computing error norms
    %
    h=Props(1,3);
    El_area(Ielem,1) = sum(vip);
    Exact_norm2(Ielem,1) = ...
    sum( (h*w.^2 + (h^3/3)*(theta_x.^2 + theta_y.^2)) .* vip' );
    Disp_norm2(Ielem,1) = ...
    sum( ( h*(w_app-w).^2 + (h^3/3)*(theta_x_app-theta_x).^2 + ...
           (h^3/3)*(theta_y_app-theta_y).^2 ) .* vip' );
    clear h
end
clear Ielem Isamp TRI_coord xip vip
%
Area = sum(El_area)
Rel_d_err = sqrt( sum(Disp_norm2) / sum(Exact_norm2) )
toc
