 function Node_cards = Rhom_nodes (side_length, sharp_angle, no_x, no_y)
%
%  Generating the equally-spaced nodal coordinates
%  and their numerical label for an equal-side 
%  rhombic domain (parallelogram) with x axis parallel
%  to one side of the parallelogram and 
%  the x axis and that side comprise a sharp angle
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%
%  Input
%  side_length:  the length of the side
%  sharp_angle:  the sharp-angle of the parallelogram (in rad)
%  no_x:  the number of nodes in rhombic x direction
%  no_y:  the number of nodes in rhombic y direction
%        
%  Output
%  Node_cards:  a matrix containing nodal point numbers and
%               coordinate of the nodes
%
del_x=side_length/(no_x-1);  del_y=side_length/(no_y-1);
x=0 :del_x: side_length;
y=0 :del_y: side_length;
[X,Y]=meshgrid(x,y);
X_rhom=zeros(size(X));
for j_X=1:size(X,2)
    X_rhom(:,j_X)=X(:,j_X)+Y(:,j_X)*cos(sharp_angle);
end
Y_rhom=Y*sin(sharp_angle);
clear X Y
Coord=[];
for i_y=1:length(y)
   Coord = [ Coord;  X_rhom(i_y,:)' Y_rhom(i_y,:)'];
end
Node_cards = zeros( size(Coord,1),3);
Ipoin =(1:size(Coord,1))';
Node_cards = [ Ipoin  Coord];
