%
%  INPUT DATA FORMAT FOR DKMT PLATE BENDING
%
%  Written by Erwin Tirta Winata and Charles Julius Salim
%  Petra Christian University, August-December 2015
%

%  Title of the problem:
Project_Title='DKMT Element';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  2  3  3  2  0.5  6  2  0  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = [
1	0	0
2	25	0
3	50	0
4	75	0
5	100	0
6	21.65063509	12.5
7	46.65063509	12.5
8	71.65063509	12.5
9	96.65063509	12.5
10	121.6506351	12.5
11	43.30127019	25
12	68.30127019	25
13	93.30127019	25
14	118.3012702	25
15	143.3012702	25
16	64.95190528	37.5
17	89.95190528	37.5
18	114.9519053	37.5
19	139.9519053	37.5
20	164.9519053	37.5
21	86.60254038	50
22	111.6025404	50
23	136.6025404	50
24	161.6025404	50
25	186.6025404	50]; % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	6
2	1	2	3	7
3	1	3	4	8
4	1	4	5	9
5	1	2	7	6
6	1	3	8	7
7	1	4	9	8
8	1	5	10	9
9	1	6	7	11
10	1	7	8	12
11	1	8	9	13
12	1	9	10	14
13	1	7	12	11
14	1	8	13	12
15	1	9	14	13
16	1	10	15	14
17	1	11	12	16
18	1	12	13	17
19	1	13	14	18
20	1	14	15	19
21	1	12	17	16
22	1	13	18	17
23	1	14	19	18
24	1	15	20	19
25	1	16	17	21
26	1	17	18	22
27	1	18	19	23
28	1	19	20	24
29	1	17	22	21
30	1	18	23	22
31	1	19	24	23
32	1	20	25	24
];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
5	1	0	0	0	0	0
4	1	0	0	0	0	0
3	1	0	0	0	0	0
2	1	0	0	0	0	0
1	1	0	0	0	0	0
6	1	0	0	0	0	0
11	1	0	0	0	0	0
16	1	0	0	0	0	0
21	1	0	0	0	0	0
22	1	0	0	0	0	0
23	1	0	0	0	0	0
24	1	0	0	0	0	0
25	1	0	0	0	0	0
20	1	0	0	0	0	0
15	1	0	0	0	0	0
10	1	0	0	0	0	0];


CoordCont=[5 4 3 2 1 6 11 16 21 22 23 24 25 20 15 10 5];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  10.92 0.3 0.1];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:32]';
Body_f= [N_b  ones(32,1)   zeros(32,1)   zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Thin plate solutions
%  l/h=10 ---> 2.218E-09, thick plate theory, approximately: 2.5E-9
%  L/h=100 ---> 2.218E-06
%  L/h=10000 ---> 2.218
