%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 28 October 2005
%  Update:  24 March 2006
%

%  Title of the problem:
Project_Title='A Quarter of the SS-C Plate Bending with 15x15 Regularly-distributed Nodes';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements
Control_cards = [3  1  6  3  2  0  6  2  1  3];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Rect_nodes(50,50,8,8); % mm

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 3  0  1  0   0  0  0
 4  0  1  0   0  0  0
 5  0  1  0   0  0  0
 6  0  1  0   0  0  0
 7  0  1  0   0  0  0
 8  1  1  0   0  0  0
 9  0  0  1   0  0  0
17  0  0  1   0  0  0
25  0  0  1   0  0  0
33  0  0  1   0  0  0
41  0  0  1   0  0  0
49  0  0  1   0  0  0
57  1  0  1   0  0  0
16  1  0  0   0  0  0
24  1  0  0   0  0  0
32  1  0  0   0  0  0
40  1  0  0   0  0  0
48  1  0  0   0  0  0
56  1  0  0   0  0  0
64  1  0  0   0  0  0
58  1  0  0   0  0  0
59  1  0  0   0  0  0
60  1  0  0   0  0  0
61  1  0  0   0  0  0
62  1  0  0   0  0  0
63  1  0  0   0  0  0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
1  2E6 0.3 20 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 1   -1E-3  0   0 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:98 ]';
Body_f= [ N_b  zeros(98,1)  zeros(98,1)  zeros(98,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
