%
%  INPUT DATA FORMAT FOR DKMT PLATE BENDING
%
%  Written by Erwin Tirta Winata and Charles Julius Salim
%  Petra Christian University, August-December 2015
%

%  Title of the problem:
Project_Title='DKMT Element';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
Control_cards = [3  1  1  1  1  0.5  3  2  0  1];

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Circle_Nodes2(5,1); % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	4	1	3
2	1	1	2	3
3	1	2	5	6
4	1	3	2	6
5	1	6	4	3
6	1	6	7	4];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1	0	1	1		0	0	0
 2	0	1	0		0	0	0
 5	1	1	0		0	0	0
 6	1	0	0		0	0	0
 7	1	0	1		0	0	0
 4	0	0	1		0	0	0];


CoordCont=[1 2 5 6 7 4 1];
%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  10.92 0.3 0.1];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2);
N_b=[1:6]';
Body_f= [N_b  ones(6,1)   zeros(6,1)   zeros(6,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm

%  Thin plate solutions
%  l/h=10 ---> 2.218E-09, thick plate theory, approximately: 2.5E-9
%  L/h=100 ---> 2.218E-06
%  L/h=10000 ---> 2.218
