%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 6 October 2005
%  Last modification: 28 March, 7 June 2006
%

%  Title of the problem:
Project_Title='A Quarter of the SSH-U Plate Bending with M=4';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

Control_cards = [3  2  4  4  2  0  6  2  0  2];
% Solution from the thick plate theory (max values): 
% w=2.2192E-6
% Mxx=Myy=-4.789E-04; Mxy=3.247E-04;
% Qx=Qy=3.33E-05

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Rect_nodes(50,50,5,5); % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	7
2	1	2	3	8
3	1	3	4	9
4	1	4	5	10
5	1	1	7	6
6	1	2	8	7
7	1	3	9	8
8	1	4	10	9
9	1	6	7	12
10	1	7	8	13
11	1	8	9	14
12	1	9	10	15
13	1	6	12	11
14	1	7	13	12
15	1	8	14	13
16	1	9	15	14
17	1	11	12	17
18	1	12	13	18
19	1	13	14	19
20	1	14	15	20
21	1	11	17	16
22	1	12	18	17
23	1	13	19	18
24	1	14	20	19
25	1	16	17	22
26	1	17	18	23
27	1	18	19	24
28	1	19	20	25
29	1	16	22	21
30	1	17	23	22
31	1	18	24	23
32	1	19	25	24 ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 3  0  1  0   0  0  0
 4  0  1  0   0  0  0
 5  1  1  0   0  0  0
 6  0  0  1   0  0  0
11  0  0  1   0  0  0
16  0  0  1   0  0  0
21  1  0  1   0  0  0
10  1  1  0   0  0  0
15  1  1  0   0  0  0
20  1  1  0   0  0  0
25  1  1  1   0  0  0
22  1  0  1   0  0  0
23  1  0  1   0  0  0
24  1  0  1   0  0  0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:32 ]';
Body_f= [ N_b  -1E-6*ones(32,1)  zeros(32,1)  zeros(32,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
