%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 6 October 2005
%  Last modification: 28 March 2006
%

%  Title of the problem:
Project_Title='A Quarter of the SSH-U Plate Bending with M=6';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

Control_cards = [3  2  4  4  2  0  6  2  0  3];
% Solution from the thick plate theory (max values): 
% w=2.2192E-6
% Mxx=Myy=-4.789E-04; Mxy=3.247E-04;
% Qx=Qy=3.33E-05

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards = Rect_nodes(50,50,7,7); % mm

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=[
1	1	1	2	8
2	1	2	3	9
3	1	3	4	10
4	1	4	5	11
5	1	5	6	12
6	1	6	7	13
7	1	2	9	8
8	1	3	10	9
9	1	4	11	10
10	1	5	12	11
11	1	6	13	12
12	1	7	14	13
13	1	8	9	15
14	1	9	10	16
15	1	10	11	17
16	1	11	12	18
17	1	12	13	19
18	1	13	14	20
19	1	9	16	15
20	1	10	17	16
21	1	11	18	17
22	1	12	19	18
23	1	13	20	19
24	1	14	21	20
25	1	15	16	22
26	1	16	17	23
27	1	17	18	24
28	1	18	19	25
29	1	19	20	26
30	1	20	21	27
31	1	16	23	22
32	1	17	24	23
33	1	18	25	24
34	1	19	26	25
35	1	20	27	26
36	1	21	28	27
37	1	22	23	29
38	1	23	24	30
39	1	24	25	31
40	1	25	26	32
41	1	26	27	33
42	1	27	28	34
43	1	23	30	29
44	1	24	31	30
45	1	25	32	31
46	1	26	33	32
47	1	27	34	33
48	1	28	35	34
49	1	29	30	36
50	1	30	31	37
51	1	31	32	38
52	1	32	33	39
53	1	33	34	40
54	1	34	35	41
55	1	30	37	36
56	1	31	38	37
57	1	32	39	38
58	1	33	40	39
59	1	34	41	40
60	1	35	42	41
61	1	36	37	43
62	1	37	38	44
63	1	38	39	45
64	1	39	40	46
65	1	40	41	47
66	1	41	42	48
67	1	37	44	43
68	1	38	45	44
69	1	39	46	45
70	1	40	47	46
71	1	41	48	47
72	1	42	49	48 ];

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
 1  0  1  1   0  0  0
 2  0  1  0   0  0  0
 3  0  1  0   0  0  0
 4  0  1  0   0  0  0
 5  0  1  0   0  0  0
 6  0  1  0   0  0  0
 7  1  1  0   0  0  0
 8  0  0  1   0  0  0
15  0  0  1   0  0  0
22  0  0  1   0  0  0
29  0  0  1   0  0  0
36  0  0  1   0  0  0
43  1  0  1   0  0  0
14  1  1  0   0  0  0
21  1  1  0   0  0  0
28  1  1  0   0  0  0
35  1  1  0   0  0  0
42  1  1  0   0  0  0
49  1  1  1   0  0  0
44  1  0  1   0  0  0
45  1  0  1   0  0  0
46  1  0  1   0  0  0
47  1  0  1   0  0  0
48  1  0  1   0  0  0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:72 ]';
Body_f= [ N_b  -1E-6*ones(72,1)  zeros(72,1)  zeros(72,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
