%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%  Last modification: 27 Sept 2006
%

%  Title of the problem:
Project_Title='SS-U Rhombic Plate Bending with M=16';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

Control_cards = [3  2  2  2  2  0.5  6  2  0  1];
% Solution from the thin plate theory (max values): 
% w=2.23E-7
% Mxx= ;Myy= ; Mxy= ;
% Qx= ; Qy= 

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=Rhom_nodes(100, pi/6, 17, 17);

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=Tri_mesh_A( 17, 17);

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	0	0	0	0	0
2	1	0	0	0	0	0
3	1	0	0	0	0	0
4	1	0	0	0	0	0
5	1	0	0	0	0	0
6	1	0	0	0	0	0
7	1	0	0	0	0	0
8	1	0	0	0	0	0
9	1	0	0	0	0	0
10	1	0	0	0	0	0
11	1	0	0	0	0	0
12	1	0	0	0	0	0
13	1	0	0	0	0	0
14	1	0	0	0	0	0
15	1	0	0	0	0	0
16	1	0	0	0	0	0
17	1	0	0	0	0	0
18	1	0	0	0	0	0
35	1	0	0	0	0	0
52	1	0	0	0	0	0
69	1	0	0	0	0	0
86	1	0	0	0	0	0
103	1	0	0	0	0	0
120	1	0	0	0	0	0
137	1	0	0	0	0	0
154	1	0	0	0	0	0
171	1	0	0	0	0	0
188	1	0	0	0	0	0
205	1	0	0	0	0	0
222	1	0	0	0	0	0
239	1	0	0	0	0	0
256	1	0	0	0	0	0
273	1	0	0	0	0	0
34	1	0	0	0	0	0
51	1	0	0	0	0	0
68	1	0	0	0	0	0
85	1	0	0	0	0	0
102	1	0	0	0	0	0
119	1	0	0	0	0	0
136	1	0	0	0	0	0
153	1	0	0	0	0	0
170	1	0	0	0	0	0
187	1	0	0	0	0	0
204	1	0	0	0	0	0
221	1	0	0	0	0	0
238	1	0	0	0	0	0
255	1	0	0	0	0	0
272	1	0	0	0	0	0
289	1	0	0	0	0	0
274	1	0	0	0	0	0
275	1	0	0	0	0	0
276	1	0	0	0	0	0
277	1	0	0	0	0	0
278	1	0	0	0	0	0
279	1	0	0	0	0	0
280	1	0	0	0	0	0
281	1	0	0	0	0	0
282	1	0	0	0	0	0
283	1	0	0	0	0	0
284	1	0	0	0	0	0
285	1	0	0	0	0	0
286	1	0	0	0	0	0
287	1	0	0	0	0	0
288	1	0	0	0	0	0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:512 ]';
Body_f= [ N_b  -1E-6*ones(512,1)  zeros(512,1)  zeros(512,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
