%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%  Last modification: 27 Sept 2006
%

%  Title of the problem:
Project_Title='SS-U Rhombic Plate Bending with M=32';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

% Control_cards = [3  2  3  3  2  0  6  2  0  2];
Control_cards = [3  2  2  2  2  0.5  6  2  0  1];
% Solution from the thin plate theory (max values): 
% w=2.23E-7
% Mxx= ;Myy= ; Mxy= ;
% Qx= ; Qy= 

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=Rhom_nodes(100, pi/6, 33, 33);

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=Tri_mesh_A( 33, 33);

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	0	0	0	0	0
2	1	0	0	0	0	0
3	1	0	0	0	0	0
4	1	0	0	0	0	0
5	1	0	0	0	0	0
6	1	0	0	0	0	0
7	1	0	0	0	0	0
8	1	0	0	0	0	0
9	1	0	0	0	0	0
10	1	0	0	0	0	0
11	1	0	0	0	0	0
12	1	0	0	0	0	0
13	1	0	0	0	0	0
14	1	0	0	0	0	0
15	1	0	0	0	0	0
16	1	0	0	0	0	0
17	1	0	0	0	0	0
18	1	0	0	0	0	0
19	1	0	0	0	0	0
20	1	0	0	0	0	0
21	1	0	0	0	0	0
22	1	0	0	0	0	0
23	1	0	0	0	0	0
24	1	0	0	0	0	0
25	1	0	0	0	0	0
26	1	0	0	0	0	0
27	1	0	0	0	0	0
28	1	0	0	0	0	0
29	1	0	0	0	0	0
30	1	0	0	0	0	0
31	1	0	0	0	0	0
32	1	0	0	0	0	0
33	1	0	0	0	0	0
34	1	0	0	0	0	0
67	1	0	0	0	0	0
100	1	0	0	0	0	0
133	1	0	0	0	0	0
166	1	0	0	0	0	0
199	1	0	0	0	0	0
232	1	0	0	0	0	0
265	1	0	0	0	0	0
298	1	0	0	0	0	0
331	1	0	0	0	0	0
364	1	0	0	0	0	0
397	1	0	0	0	0	0
430	1	0	0	0	0	0
463	1	0	0	0	0	0
496	1	0	0	0	0	0
529	1	0	0	0	0	0
562	1	0	0	0	0	0
595	1	0	0	0	0	0
628	1	0	0	0	0	0
661	1	0	0	0	0	0
694	1	0	0	0	0	0
727	1	0	0	0	0	0
760	1	0	0	0	0	0
793	1	0	0	0	0	0
826	1	0	0	0	0	0
859	1	0	0	0	0	0
892	1	0	0	0	0	0
925	1	0	0	0	0	0
958	1	0	0	0	0	0
991	1	0	0	0	0	0
1024	1	0	0	0	0	0
1057	1	0	0	0	0	0
66	1	0	0	0	0	0
99	1	0	0	0	0	0
132	1	0	0	0	0	0
165	1	0	0	0	0	0
198	1	0	0	0	0	0
231	1	0	0	0	0	0
264	1	0	0	0	0	0
297	1	0	0	0	0	0
330	1	0	0	0	0	0
363	1	0	0	0	0	0
396	1	0	0	0	0	0
429	1	0	0	0	0	0
462	1	0	0	0	0	0
495	1	0	0	0	0	0
528	1	0	0	0	0	0
561	1	0	0	0	0	0
594	1	0	0	0	0	0
627	1	0	0	0	0	0
660	1	0	0	0	0	0
693	1	0	0	0	0	0
726	1	0	0	0	0	0
759	1	0	0	0	0	0
792	1	0	0	0	0	0
825	1	0	0	0	0	0
858	1	0	0	0	0	0
891	1	0	0	0	0	0
924	1	0	0	0	0	0
957	1	0	0	0	0	0
990	1	0	0	0	0	0
1023	1	0	0	0	0	0
1056	1	0	0	0	0	0
1089	1	0	0	0	0	0
1058	1	0	0	0	0	0
1059	1	0	0	0	0	0
1060	1	0	0	0	0	0
1061	1	0	0	0	0	0
1062	1	0	0	0	0	0
1063	1	0	0	0	0	0
1064	1	0	0	0	0	0
1065	1	0	0	0	0	0
1066	1	0	0	0	0	0
1067	1	0	0	0	0	0
1068	1	0	0	0	0	0
1069	1	0	0	0	0	0
1070	1	0	0	0	0	0
1071	1	0	0	0	0	0
1072	1	0	0	0	0	0
1073	1	0	0	0	0	0
1074	1	0	0	0	0	0
1075	1	0	0	0	0	0
1076	1	0	0	0	0	0
1077	1	0	0	0	0	0
1078	1	0	0	0	0	0
1079	1	0	0	0	0	0
1080	1	0	0	0	0	0
1081	1	0	0	0	0	0
1082	1	0	0	0	0	0
1083	1	0	0	0	0	0
1084	1	0	0	0	0	0
1085	1	0	0	0	0	0
1086	1	0	0	0	0	0
1087	1	0	0	0	0	0
1088	1	0	0	0	0	0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:2048 ]';
Body_f= [ N_b  -1E-6*ones(2048,1)  zeros(2048,1)  zeros(2048,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
