%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%  Last modification: 27 Sept 2006
%

%  Title of the problem:
Project_Title='SS-U Rhombic Plate Bending with M=64';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

Control_cards = [3  2  3  3  2  0  6  2  0  2];
% Solution from the thin plate theory (max values): 
% w=2.23E-7
% Mxx= ;Myy= ; Mxy= ;
% Qx= ; Qy= 

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=Rhom_nodes(100, pi/6, 65, 65);

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=Tri_mesh_A( 65, 65);

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	0	0	0	0	0
2	1	0	0	0	0	0
3	1	0	0	0	0	0
4	1	0	0	0	0	0
5	1	0	0	0	0	0
6	1	0	0	0	0	0
7	1	0	0	0	0	0
8	1	0	0	0	0	0
9	1	0	0	0	0	0
10	1	0	0	0	0	0
11	1	0	0	0	0	0
12	1	0	0	0	0	0
13	1	0	0	0	0	0
14	1	0	0	0	0	0
15	1	0	0	0	0	0
16	1	0	0	0	0	0
17	1	0	0	0	0	0
18	1	0	0	0	0	0
19	1	0	0	0	0	0
20	1	0	0	0	0	0
21	1	0	0	0	0	0
22	1	0	0	0	0	0
23	1	0	0	0	0	0
24	1	0	0	0	0	0
25	1	0	0	0	0	0
26	1	0	0	0	0	0
27	1	0	0	0	0	0
28	1	0	0	0	0	0
29	1	0	0	0	0	0
30	1	0	0	0	0	0
31	1	0	0	0	0	0
32	1	0	0	0	0	0
33	1	0	0	0	0	0
34	1	0	0	0	0	0
35	1	0	0	0	0	0
36	1	0	0	0	0	0
37	1	0	0	0	0	0
38	1	0	0	0	0	0
39	1	0	0	0	0	0
40	1	0	0	0	0	0
41	1	0	0	0	0	0
42	1	0	0	0	0	0
43	1	0	0	0	0	0
44	1	0	0	0	0	0
45	1	0	0	0	0	0
46	1	0	0	0	0	0
47	1	0	0	0	0	0
48	1	0	0	0	0	0
49	1	0	0	0	0	0
50	1	0	0	0	0	0
51	1	0	0	0	0	0
52	1	0	0	0	0	0
53	1	0	0	0	0	0
54	1	0	0	0	0	0
55	1	0	0	0	0	0
56	1	0	0	0	0	0
57	1	0	0	0	0	0
58	1	0	0	0	0	0
59	1	0	0	0	0	0
60	1	0	0	0	0	0
61	1	0	0	0	0	0
62	1	0	0	0	0	0
63	1	0	0	0	0	0
64	1	0	0	0	0	0
65	1	0	0	0	0	0
66	1	0	0	0	0	0
131	1	0	0	0	0	0
196	1	0	0	0	0	0
261	1	0	0	0	0	0
326	1	0	0	0	0	0
391	1	0	0	0	0	0
456	1	0	0	0	0	0
521	1	0	0	0	0	0
586	1	0	0	0	0	0
651	1	0	0	0	0	0
716	1	0	0	0	0	0
781	1	0	0	0	0	0
846	1	0	0	0	0	0
911	1	0	0	0	0	0
976	1	0	0	0	0	0
1041	1	0	0	0	0	0
1106	1	0	0	0	0	0
1171	1	0	0	0	0	0
1236	1	0	0	0	0	0
1301	1	0	0	0	0	0
1366	1	0	0	0	0	0
1431	1	0	0	0	0	0
1496	1	0	0	0	0	0
1561	1	0	0	0	0	0
1626	1	0	0	0	0	0
1691	1	0	0	0	0	0
1756	1	0	0	0	0	0
1821	1	0	0	0	0	0
1886	1	0	0	0	0	0
1951	1	0	0	0	0	0
2016	1	0	0	0	0	0
2081	1	0	0	0	0	0
2146	1	0	0	0	0	0
2211	1	0	0	0	0	0
2276	1	0	0	0	0	0
2341	1	0	0	0	0	0
2406	1	0	0	0	0	0
2471	1	0	0	0	0	0
2536	1	0	0	0	0	0
2601	1	0	0	0	0	0
2666	1	0	0	0	0	0
2731	1	0	0	0	0	0
2796	1	0	0	0	0	0
2861	1	0	0	0	0	0
2926	1	0	0	0	0	0
2991	1	0	0	0	0	0
3056	1	0	0	0	0	0
3121	1	0	0	0	0	0
3186	1	0	0	0	0	0
3251	1	0	0	0	0	0
3316	1	0	0	0	0	0
3381	1	0	0	0	0	0
3446	1	0	0	0	0	0
3511	1	0	0	0	0	0
3576	1	0	0	0	0	0
3641	1	0	0	0	0	0
3706	1	0	0	0	0	0
3771	1	0	0	0	0	0
3836	1	0	0	0	0	0
3901	1	0	0	0	0	0
3966	1	0	0	0	0	0
4031	1	0	0	0	0	0
4096	1	0	0	0	0	0
4161	1	0	0	0	0	0
130	1	0	0	0	0	0
195	1	0	0	0	0	0
260	1	0	0	0	0	0
325	1	0	0	0	0	0
390	1	0	0	0	0	0
455	1	0	0	0	0	0
520	1	0	0	0	0	0
585	1	0	0	0	0	0
650	1	0	0	0	0	0
715	1	0	0	0	0	0
780	1	0	0	0	0	0
845	1	0	0	0	0	0
910	1	0	0	0	0	0
975	1	0	0	0	0	0
1040	1	0	0	0	0	0
1105	1	0	0	0	0	0
1170	1	0	0	0	0	0
1235	1	0	0	0	0	0
1300	1	0	0	0	0	0
1365	1	0	0	0	0	0
1430	1	0	0	0	0	0
1495	1	0	0	0	0	0
1560	1	0	0	0	0	0
1625	1	0	0	0	0	0
1690	1	0	0	0	0	0
1755	1	0	0	0	0	0
1820	1	0	0	0	0	0
1885	1	0	0	0	0	0
1950	1	0	0	0	0	0
2015	1	0	0	0	0	0
2080	1	0	0	0	0	0
2145	1	0	0	0	0	0
2210	1	0	0	0	0	0
2275	1	0	0	0	0	0
2340	1	0	0	0	0	0
2405	1	0	0	0	0	0
2470	1	0	0	0	0	0
2535	1	0	0	0	0	0
2600	1	0	0	0	0	0
2665	1	0	0	0	0	0
2730	1	0	0	0	0	0
2795	1	0	0	0	0	0
2860	1	0	0	0	0	0
2925	1	0	0	0	0	0
2990	1	0	0	0	0	0
3055	1	0	0	0	0	0
3120	1	0	0	0	0	0
3185	1	0	0	0	0	0
3250	1	0	0	0	0	0
3315	1	0	0	0	0	0
3380	1	0	0	0	0	0
3445	1	0	0	0	0	0
3510	1	0	0	0	0	0
3575	1	0	0	0	0	0
3640	1	0	0	0	0	0
3705	1	0	0	0	0	0
3770	1	0	0	0	0	0
3835	1	0	0	0	0	0
3900	1	0	0	0	0	0
3965	1	0	0	0	0	0
4030	1	0	0	0	0	0
4095	1	0	0	0	0	0
4160	1	0	0	0	0	0
4225	1	0	0	0	0	0
4162	1	0	0	0	0	0
4163	1	0	0	0	0	0
4164	1	0	0	0	0	0
4165	1	0	0	0	0	0
4166	1	0	0	0	0	0
4167	1	0	0	0	0	0
4168	1	0	0	0	0	0
4169	1	0	0	0	0	0
4170	1	0	0	0	0	0
4171	1	0	0	0	0	0
4172	1	0	0	0	0	0
4173	1	0	0	0	0	0
4174	1	0	0	0	0	0
4175	1	0	0	0	0	0
4176	1	0	0	0	0	0
4177	1	0	0	0	0	0
4178	1	0	0	0	0	0
4179	1	0	0	0	0	0
4180	1	0	0	0	0	0
4181	1	0	0	0	0	0
4182	1	0	0	0	0	0
4183	1	0	0	0	0	0
4184	1	0	0	0	0	0
4185	1	0	0	0	0	0
4186	1	0	0	0	0	0
4187	1	0	0	0	0	0
4188	1	0	0	0	0	0
4189	1	0	0	0	0	0
4190	1	0	0	0	0	0
4191	1	0	0	0	0	0
4192	1	0	0	0	0	0
4193	1	0	0	0	0	0
4194	1	0	0	0	0	0
4195	1	0	0	0	0	0
4196	1	0	0	0	0	0
4197	1	0	0	0	0	0
4198	1	0	0	0	0	0
4199	1	0	0	0	0	0
4200	1	0	0	0	0	0
4201	1	0	0	0	0	0
4202	1	0	0	0	0	0
4203	1	0	0	0	0	0
4204	1	0	0	0	0	0
4205	1	0	0	0	0	0
4206	1	0	0	0	0	0
4207	1	0	0	0	0	0
4208	1	0	0	0	0	0
4209	1	0	0	0	0	0
4210	1	0	0	0	0	0
4211	1	0	0	0	0	0
4212	1	0	0	0	0	0
4213	1	0	0	0	0	0
4214	1	0	0	0	0	0
4215	1	0	0	0	0	0
4216	1	0	0	0	0	0
4217	1	0	0	0	0	0
4218	1	0	0	0	0	0
4219	1	0	0	0	0	0
4220	1	0	0	0	0	0
4221	1	0	0	0	0	0
4222	1	0	0	0	0	0
4223	1	0	0	0	0	0
4224	1	0	0	0	0	0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:8192 ]';
Body_f= [ N_b  -1E-6*ones(8192,1)  zeros(8192,1)  zeros(8192,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
