%
%  INPUT DATA FORMAT
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%  Last modification: 27 Sept 2006
%

%  Title of the problem:
Project_Title='SS-U Rhombic Plate Bending with M=8';

%  Control Data
%  Ndofn:  Number of degrees of freedom per nodal point
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline (not complete!!)
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%            1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic
%  N_layer:  The number of influence layer(s) (1-5)
%  theta_type:  The options for the correlation parameter:
%               1.  Constant through out the elements
%               2.  Vary according to the number of nodes in the DOI
%  theta:  The correlation parameter for theta_type=1, 
%          The factor for the upper bound of theta, lies between 0 and 1
%          1: theta is at the upper bound, 0: theta is at the lower bound
%          0.5:  theta is at the middle between the upper and lower bounds
%          For Cor_type=2 and theta_type=2, it has no effect.
%  Nsamp:  The number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%  Ngaus:  The order of gaussian numerical integration for 
%          computation of line integral
%  Mesh_gen:  Automatic mesh generation by Delaunay triangulation:
%             0-No,  1-Yes
%  shear_type:  Option for the method to calculate the shear forces:
%  1. Using the shear strains, 2. Using kriging from nodal moments
%  3. Using kriging from nodal displacements

Control_cards = [3  2  2  2  2  0.5  6  2  0  1];
% Solution from the thin plate theory (max values): 
% w=2.23E-7
% Mxx= ;Myy= ; Mxy= ;
% Qx= ; Qy= 

%  Nodal Coordinate
%  Ipoin:  Nodal point number
%  Coord:  Coordinate of the node
Node_cards=Rhom_nodes(100, pi/6, 9, 9);

%  Element Connectivity
%  Numel:  Element number
%  Matno:  Material property number
%  Lnods:  Element node numbers listed per each element
Element_cards=Tri_mesh_A( 9, 9);

%  Nodal Boundary Condition
%  Nofix:  Restrained node number
%  Ifpre:  Condition of restraint / Restraint code
%  Presc:  Prescribed value of nodal displacements
Restrained_cards=[ 
1	1	0	0	0	0	0
2	1	0	0	0	0	0
3	1	0	0	0	0	0
4	1	0	0	0	0	0
5	1	0	0	0	0	0
6	1	0	0	0	0	0
7	1	0	0	0	0	0
8	1	0	0	0	0	0
9	1	0	0	0	0	0
10	1	0	0	0	0	0
19	1	0	0	0	0	0
28	1	0	0	0	0	0
37	1	0	0	0	0	0
46	1	0	0	0	0	0
55	1	0	0	0	0	0
64	1	0	0	0	0	0
73	1	0	0	0	0	0
18	1	0	0	0	0	0
27	1	0	0	0	0	0
36	1	0	0	0	0	0
45	1	0	0	0	0	0
54	1	0	0	0	0	0
63	1	0	0	0	0	0
72	1	0	0	0	0	0
81	1	0	0	0	0	0
74	1	0	0	0	0	0
75	1	0	0	0	0	0
76	1	0	0	0	0	0
77	1	0	0	0	0	0
78	1	0	0	0	0	0
79	1	0	0	0	0	0
80	1	0	0	0	0	0 ];

%  Material Properties
%  Numat:  Material identification number
%  Props:  Elastic modulus, Poisson's ratio, plate thickness,
%          mass density
Material_cards=[ % KN/mm2
 1  2E6 0.3 1 ];

%  Nodal Force
%  Lodpt:  Node number
%  Point:  Applied nodal point forces
Applied_load_cards=[ % KN
 ];

%  Transverse Body Force (KN/mm2 and KN-mm/mm2)
N_b=[ 1:128 ]';
Body_f= [ N_b  -1E-6*ones(128,1)  zeros(128,1)  zeros(128,1)];

%  Traction Force
%  Trac_f:  Applied traction force
Trac_f=[ 
 ]; % KN/mm
