function [Shape, Bb] = Shape_fun(Phi, DxPhi, DyPhi, n_Nodes)
 
%  Establishing shape function matrix and bending strain-displacement
%  matrices at sampling point for a plate element 
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 31 Jan 2006
%
%  Input
%  Phi:  Row matrix of shape function values at a sampling point
%  DxPhi, DyPhi:  Row matrix of shape function derivatives 
%                 with respect to x and y, respectively, at a sampling point
%  n_Nodes:  Number of nodes in the influence domain
%
%  Output
%  Shape:  The shape function matrix for plate
%  Bb:  The bending strain-displacement matrix for plate
%
Shape=zeros(3,3*n_Nodes);
for i_sh=1:n_Nodes
    Shape(1, 3*i_sh-2)=Phi(1,i_sh);
    Shape(2, 3*i_sh-1)=Phi(1,i_sh);
    Shape(3, 3*i_sh)=Phi(1,i_sh);
end
clear i_sh
%
Bb=zeros(3,3*n_Nodes);
for i_d=1:n_Nodes
    Bb(1, 3*i_d-1)=DxPhi(1,i_d);
    Bb(2, 3*i_d)=DyPhi(1,i_d);
    Bb(3, 3*i_d-1)=DyPhi(1,i_d);
    Bb(3, 3*i_d)=DxPhi(1,i_d);
end