function  Shears = Shear2_fun( Ielem, Lnods, Coord, Cor_type, ...
                               theta, P_order, Nodes, Node_Moments)

%  Shears = Shear2_fun( Ielem, Lnods, Coord, Cor_type, ...
%                       theta, P_order, Nodes, Node_Moments)
%
%  To calculate shear forces using kriging from nodal moments
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 15 March 2006
%  Modification:
%
%  Input
%  Ielem:  Current element numberY
%  Lnods:  Element node numbers listed per each elementY
%  Coord:  Coordinate of the nodesY
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic splineY
%  theta:  The correlation parameterY
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolationY
%  Nodes  : Node numbers in an influence domainY
%  Node_Moments: (Mxx Myy Mxy)' at all nodes in the structureY
%
%  Output
%  Shears:  (Qxz Qyz)' at the vertices
%

%  Identify the moments at the element nodal points
%  ---> El_m
El_m= Node_Moments(:,Nodes);  clear Node_Moments
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:);  clear Nodes
d_max = Max_Distance( Coord_DOI);
%
%  Kriging shape functions and their derivatives
%
TRI_coord=Coord(Lnods(Ielem,:),:);
[PHI, DxPHI, DyPHI] = ...
 Kriging_shapef( Coord_DOI, theta, d_max, P_order, TRI_coord, Cor_type);
clear Coord_DOI d_max TRI_coord
%
%  Shear forces
%
Shears= [ (DxPHI*El_m(1,:)' + DyPHI*El_m(3,:)')'
          (DxPHI*El_m(3,:)' + DyPHI*El_m(2,:)')' ];