function  [Node_Shears, Ave_Shears] = Shear_ave(Npoin, Lnods, Shears)

%  [Node_Shears, Ave_Shears] = Shear_ave(Npoin, Lnods, Shears)
%
%  To calculate the average values of shears 
%  at common nodes
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification: 15 March 2006
%
%  Input
%  Npoin:  Total number of nodal points in the structure
%  Lnods:  Element node numbers listed per each element
%  Shears :  (Qxz Qyz)' at the vertices for each element
%
%  Output
%  Node_Shears:  (Qxz Qyz)' at all nodes
%  Ave_Shears:   (Qxz Qyz)' at the vertices for each element
%

%  Averaging and
%  assigning the averaged values to each element
%
Node_Shears=zeros(2,Npoin);
Ave_Shears=Shears;
for Ipoin=1:Npoin
    [I,J]=find(Lnods==Ipoin);
    Node_Shears(:,Ipoin)= mean( Shears(:,3*(I-1)+J), 2);
    for ii=1:size(I,1)
        Ave_Shears(:, 3*(I(ii)-1)+J(ii) )= Node_Shears(:,Ipoin);
    end
end