function Rmom = Tracps_Krig (Nodes, n_Nodes, Coord, Props, IMatno, ...
                              i_TRI, Trac_f, Ngaus, Ndofn, theta, Cor_type, P_order, Ielem, Lnods,Au, Nsamp)

%  RTrac = Tracps_Krig (Nodes, n_Nodes, Coord, Props, IMatno, ...
%                       i_TRI, Trac_f, Ngaus, Ndofn, theta, Cor_type, P_order)
%                    
%  Calculate the element equivalent nodal forces from
%  traction force
%  
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 25 August 2005
%  Modification: 8 Sept 2005, 8 Nov 2006
%
%  Input
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Coord:  Coordinates of the nodes
%  Props:  Elastic modulus, Poisson's ratio, material thickness
%  IMatno: Current material property number
%  Ndofn:  Number of degrees of freedom per nodal point
%  i_TRI:  The row number of Trac_f
%  Trac_f:  Matrix of applied traction force information
%  theta:  The correlation parameter, applies only for theta_type=1
%  Cor_type:  Type of correlation function
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%
%  Output
%  RTrac:  The equivalent nodal force vector
%
Thick=Props(IMatno,3);
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:)  
d_max = Max_Distance( Coord_DOI)
%
%  Sampling points and their weights (in local coordinates)
%
TRI_coord=Coord(Lnods(Ielem,:),:);
%
%  Gaussian sampling points and their weights
%
A=Trac_f(i_TRI,1);  B=Trac_f(i_TRI,2);
x1=[Coord(A,1); Coord(A,2)]; %koordinat A
x2=[Coord(B,1); Coord(B,2)]; %koordinat B
[xipb, vipb] = Line_integr (x1,x2,Ngaus) ;
%
%  Rotation from x y to n s
%
Lenght=sqrt((x2(1,1)-x1(1,1))^2+(x2(2,1)-x1(2,1))^2);
n1= (x2(2,1)-x1(2,1))/Lenght;
n2= (x2(1,1)-x1(1,1))/Lenght;
n=[ n1 -n2; n2  n1];
%
%  The traction vector at sampling points
%
warning off
m = (x2(2)-x1(2))/(x2(1)-x1(1));
warning on
if abs(m)<=1 %horizontal
   % tx
   X=[ x1(1) x2(1) 0.5*(x1(1)+x2(1)) ];
   Y=[ Trac_f(i_TRI,3) Trac_f(i_TRI,5) Trac_f(i_TRI,7) ];
   Mn=polyval( polyfit(X,Y,2), xipb(1,:) );
   % ty
   X=[ x1(1) x2(1) 0.5*(x1(1)+x2(1)) ];
   Y=[ Trac_f(i_TRI,4) Trac_f(i_TRI,6) Trac_f(i_TRI,8) ];
   Mns=polyval( polyfit(X,Y,2), xipb(1,:) );
else %vertical
   % tx
   X=[ x1(2) x2(2) 0.5*(x1(2)+x2(2)) ];
   Y=[ Trac_f(i_TRI,3) Trac_f(i_TRI,5) Trac_f(i_TRI,7) ];
   Mn=polyval( polyfit(X,Y,2), xipb(2,:) );
   % ty
   X=[ x1(2) x2(2) 0.5*(x1(2)+x2(2)) ];
   Y=[ Trac_f(i_TRI,4) Trac_f(i_TRI,6) Trac_f(i_TRI,8) ];
   Mns=polyval( polyfit(X,Y,2), xipb(2,:) );
end
Trac=[Mn; Mns];

Tracxy=n*Trac
%
%  Kriging shape functions
%
[PHI] = Kriging_shapef( Coord_DOI, theta, d_max, P_order, xipb', Cor_type);
clear Coord_DOI
%
%  Numerical integration untuk di tepi saja
%
Rmom=zeros(n_Nodes*Ndofn,1);
Nat_DxPHI=zeros(1,n_Nodes);
Nat_DyPHI=zeros(1,n_Nodes);
for Igaus = 1:Ngaus
    [N, DN, C, S, L, A] = MITC_shape_f (TRI_coord, xipb(:,Igaus)); %harus selalu linieaar
   [Shape1, Shape2] = Shape_fun_MITC3(N, DN, TRI_coord, PHI(Igaus,:), Nat_DxPHI, Nat_DyPHI, ...
                                C, S, A, n_Nodes,L, Nodes, Lnods(Ielem,:));
   %  The shape function matrix
     Au
     Shape=Shape1+Shape2*Au;
   %  Multiplication
   Rmom = Rmom + Shape'*[0; Tracxy(:,Igaus)]*vipb(1,Igaus);
end    
