function  El_cards= Tri_mesh_A(no_x, no_y)
%
%  Generating the element connectivity matrix 
%  for mesh comprising of triangular elements
%  whose hypotenuse run from upper-left to lower-down (Mesh A)
%  The nodes are the output of Rect_nodes.m or Rhom_nodes.m
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 September 2006
%
%  Input
%  no_x:  the number of nodes in rhombic x direction
%  no_y:  the number of nodes in rhombic y direction
%        
%  Output
%  El_cards:  a matrix containing element numbers,
%             material property numbers, and
%             element connectivity for all elements
%
Nelem_x=no_x-1;  Nelem_y=no_y-1;
Nelem=2*Nelem_x*Nelem_y;
Lnods=zeros(Nelem,3);
El_cards= [ (1:Nelem)' ones(Nelem,1) Lnods ];

x_cards1=1:Nelem_x;
for Ielem_y=1:Nelem_y
    x_cards= x_cards1+2*(Ielem_y-1)*Nelem_x;
    El_cards(x_cards,3)= x_cards1'+(Ielem_y-1)*no_x;
    El_cards(x_cards,4)= El_cards(x_cards,3)+1;
    El_cards(x_cards,5)= El_cards(x_cards,3)+no_x;
end

x_cards2= x_cards1 + Nelem_x;
for Ielem_y=1:Nelem_y
    x_cards= x_cards2+2*(Ielem_y-1)*Nelem_x;
    El_cards(x_cards,3)= (x_cards1'+1)+(Ielem_y-1)*no_x;
    El_cards(x_cards,4)= El_cards(x_cards,3)+no_x;
    El_cards(x_cards,5)= El_cards(x_cards,3)+no_x-1;
end
