%
%  A pre-processor program for meshing a circular domain
%  The meshing strategy ensures good aspect ratio of all elements
%  Writter:  Nopvichai Kokaew, 2003.
%  In connection with AIT Thesis No. ST-03-22
%

%=======%
%Xcircle%
%=======%

clear
%========================================%
%Xcircle input dialog box                %
%========================================%
prompt={'Enter plate radius:'...         %
       ,'Enter initial radius:'};        %
title='Geometry data - Circular/4 shape';%
lines=1;                                 %
def={'50','5'};                          %
ans=inputdlg(prompt,title,lines,def);    %
R=str2double(ans(1,1));                  %
R0=str2double(ans(2,1));                 %
clear prompt title lines def ans;        %
%========================================%


%=================================================%
%Node data generation                             %
%=================================================%
clear NDATA EDATA;                                %
N=1;                                              %
NDATA(1,1)=0;                                     %    
NDATA(1,2)=0;                                     %
for ir=1:10^6                                     %
    ANG0=0;                                       %
    ANG =(pi/2)/(ir+1);                           %
    for it=1:(ir+2)                               %
        if ir==1                                  %
            RI=R0;                                %
        else                                      %
            RI=(4+ir*2)*R0/((4+ir*2)-pi);         %
        end                                       %
        if RI>R                                   %
            break                                 %
        end                                       %
        N=N+1;                                    %
        NDATA(N,1)=RI*cos(ANG0);                  %
        NDATA(N,2)=RI*sin(ANG0);                  %
        ANG0=ANG0+ANG;                            %
    end                                           %
    if RI>R                                       %
        break                                     %
    elseif RI==R                                  %
        break                                     %
    end                                           %
    R0=RI;                                        %
end                                               %
if RI>R                                           %
ANG0=0;                                           %
ANG =(pi/2)/(ir+1);                               %
    for it=1:(ir+2)                               %
        N=N+1;                                    %
        NDATA(N,1)=R*cos(ANG0);                   %
        NDATA(N,2)=R*sin(ANG0);                   %
        ANG0=ANG0+ANG;                            %
    end                                           %
end                                               %
%=================================================%


%============================================%
%Element data generation                     %
%============================================%
EDATA(:,1:3)=delaunay(NDATA(:,1),NDATA(:,2));%
NE=length(EDATA(:,1));                       %
%============================================%


%=============================================%
%Re-connectivity                              %
%=============================================%
EDATA0=EDATA;                                 %
for ir=1:NE                                   %
           XMIN=min([NDATA(EDATA0(ir,1),1),...%
                     NDATA(EDATA0(ir,2),1),...%
                     NDATA(EDATA0(ir,3),1)]); %
                                              %
    if XMIN==NDATA(EDATA0(ir,1),1)            %
        N1=EDATA0(ir,1);                      %
        N2=EDATA0(ir,2);                      %
        N3=EDATA0(ir,3);                      %
    elseif XMIN==NDATA(EDATA0(ir,2),1)        %
        N1=EDATA0(ir,2);                      %
        N2=EDATA0(ir,1);                      %
        N3=EDATA0(ir,3);                      %
    else                                      %
        N1=EDATA0(ir,3);                      %
        N2=EDATA0(ir,1);                      %
        N3=EDATA0(ir,2);                      %
    end                                       %
    X1=NDATA(N1,1);                           %
    X2=NDATA(N2,1);                           %
    X3=NDATA(N3,1);                           %
    Y1=NDATA(N1,2);                           %
    Y2=NDATA(N2,2);                           %
    Y3=NDATA(N3,2);                           %
                                              %
    DX2=X2-X1;                                %
    DX3=X3-X1;                                %
    DY2=Y2-Y1;                                %
    DY3=Y3-Y1;                                %
                                              %
    ANG2=atan(DY2/DX2);                       %
    ANG3=atan(DY3/DX3);                       %
                                              %
    if ANG2<ANG3                              %
        EDATA(ir,1)=N1;                       %
        EDATA(ir,2)=N2;                       %
        EDATA(ir,3)=N3;                       %
    else                                      %
        EDATA(ir,1)=N1;                       %
        EDATA(ir,2)=N3;                       %
        EDATA(ir,3)=N2;                       %
    end                                       %
end                                           %
%=============================================%
    

%=====================%
%Matrix storage encore%
%MDATA=Material data  %
%BDATA=Boundary data  %
%FDATA=Nodal F. data  %
% UNIF=UNIF. F. data  %
%=====================%
MDATA=zeros(1,4);     %
BDATA=zeros(N,3);     %
FDATA=zeros(N,3);     %
UNIF =zeros(NE,1);    %
TRAC =zeros(1,5);     %
clear XYBAR;          %
%=====================%


%===============================%
%Clear unnecessary variables    %
%===============================%
clear ir it ANG ANG0 R R0 RI;   %
clear ANG2 ANG3 DX2 DX3 DY2 DY3;%
clear EDATA0 N1 N2 N3 X1 X2 X3; %
clear XMIN Y1 Y2 Y3;            %
%===============================%